# coding=utf-8
"""
library/parts.py - Auto-generated Part classes for the Python ldraw package.

Copyright (C) 2018 Matthieu Berthomé <rienafairefr@gmail.com>

This file is part of the ldraw Python package.

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.


<< This file is auto-generated, you shouldn't have to modify it>>
"""
# pylint: disable=invalid-name, line-too-long, too-many-lines

MechanicalCuboidTorsoWithStudOnFront = "24078"
MechanicalHeadAndTorso = "53988"
MechanicalTorso = "30375"
MechanicalTorsoWith4SideAttachmentCylinders = "54275"
MechanicalTorsoWithBlueInsigniaPattern = "30375ps3"
MechanicalTorsoWithOrangeDotInsigniaPattern = "30375ps4"
MechanicalTorsoWithOrangeInsigniaPattern = "30375ps1"
MechanicalTorsoWithRedDotInsigniaPattern = "30375ps7"
MechanicalTorsoWithTanInsigniaPattern = "30375ps2"
MechanicalTorsoWithTanThreeDotInsigniaPattern = "30375ps6"
MechanicalTorsoWithYellowDotInsigniaPattern = "30375ps5"
SkeletonTorso = "6260"
SkeletonTorsoWithShoulderRods = "60115"
Torso = "973"
TorsoBatmanLogoInYellowOvalWithYellowUtilityBeltAndGoldBucklePattern = "973pbo"
TorsoFemaleBlouseWithButtons_DarkPinkPanelAndNameBadgePattern = "973p9a"
TorsoFemaleTopWith2WhiteButtonsAndBlackStrapsPattern = "973p9j"
TorsoFemaleTopWithDarkPinkStripesAndFlowerNecklacePattern = "973p1z"
TorsoFemaleWithGoldStarAndZipperAndRedTiedSashAndMusclesOutlinePattern = "973pc1"
TorsoFemaleWithHarlequinBlack_WhitePattern = "973pba"
TorsoFemaleWithJacket_2Pockets_Buttons_GoldNecklacePattern = "973pbj"
TorsoFemaleWithLabCoatOverMediumBlueShirtWithIdBadgeAndSpaceShuttleLogoOnBackPattern = "973p8q"
TorsoFemaleWithLtpurpleScarfAndGrayBeltPattern = "973p7y"
TorsoFemaleWithTopWithYellowNeckAndWhiteUndershirtPattern = "973p9f"
TorsoHpJacketWith4ButtonVestAndBowTiePattern = "973ph4"
TorsoHpWithDarkRedSweaterAndYellowNeckPattern = "973ph8"
TorsoHpWithGreySweaterAndLightFleshNeckPattern = "973ph7"
TorsoHpWithJacketAndDarkRedSweaterPattern = "973ph6"
TorsoHpWithJacketAndLightGreySweaterPattern = "973ph5"
TorsoHoodedSweatshirtOpenWithDrawstringsOverDarkRedTopPattern = "973p9b"
TorsoHoodieWithWhiteLaces_BlueScrollworkAndKangarooPocketPattern = "973p1v"
TorsoHoodieWithZipperOverLimeAndGreenStripedShirtPattern = "973p99"
TorsoJacketOpenOverRedAndLightGreenTopWithNecklacePattern = "973p1w"
TorsoPirateVest_AnchorTattoo_RopeOnBackPattern = "973p3v"
TorsoPoloShirtWithPocketWithPenAndLegoLogoOnBackPattern = "973p98"
TorsoRiddlerBlackQuestionMarkOnChestAndBackAndLavenderBeltPattern = "973pbn"
TorsoSwBeltPocketsAndNecklaceBlisslFlutePattern = "973prg"
TorsoSwJawaWithDarkBrownPouchesAndBlackAndTanStraps = "973pri"
TorsoSwTankTopPattern = "973prf"
TorsoScarletSpiderPattern = "973pbs"
TorsoShirtWithRedCollarAndSpaceshipOrbitingClassicSpaceHelmetPattern = "973p97"
TorsoSpacesuitWithSilverBeltAndChestPieceWithSpaceShuttleLogoOnFrontAndBackPattern = "973p8s"
TorsoSportsShirtWith_39_OrangeBasketballAndOrangeAndRedDiamondsPattern = "973p9k"
TorsoW_GoldLionAndBeltOnRed_WhiteQuart_Pattern = "973p4l"
TorsoW_LeatherJacket_Badge_Police_BackPattern = "973p7n"
TorsoW_SwLooseDressLightBluishGreyFoldsPattern = "973psy"
TorsoW_SwLooseDressLightGreyFoldsPattern = "973pry"
TorsoW_Shirt_Badge_BlueTie_Police_BackPattern = "973p7m"
TorsoW_White_BlueTriangles_Blue_WhiteAmuletPattern = "973pwc"
TorsoW_White_BlueTriangles_Red_WhiteAmuletPattern = "973pwb"
TorsoWith_S_LogoGrey_BluePattern = "973p23"
TorsoWith_S_LogoRed_BlackPattern = "973p14"
TorsoWith_Tine_Stickers = "973d01"
TorsoWith_1RacingPattern = "973p80"
TorsoWith2ChineseLettersYellowStripePattern = "973paq"
TorsoWith3_PieceSuit_WhiteShirtAndRedTiePattern = "973pdb"
TorsoWithAirGaugeAndPocketPattern = "973p29"
TorsoWithAirplaneLogoPattern = "973p16"
TorsoWithAirplaneLogoAnd_Air_BadgePattern = "973p85"
TorsoWithAirplaneLogo_WhiteShirtAndSuitPattern = "973p8v"
TorsoWithAnchorMotifPattern = "973p09"
TorsoWithAquanautSubLogo_Zipper_AndWeightBeltPattern = "973pag"
TorsoWithAquasharkBlueSharkWithRed_X_Pattern = "973pak"
TorsoWithArcticExplorerLogo_ZipperAndWhiteFurTrimPattern = "973p92"
TorsoWithArcticParka_A2_Pattern = "973p7b"
TorsoWithArcticParkaA1Pattern = "973p7a"
TorsoWithArgyleSweaterAndWhiteShirtCollarPattern = "973p93"
TorsoWithArmorVest_SilverWolfHeadAndBlueRoundJewelPattern = "973paw"
TorsoWithAstroPattern = "973p6f"
TorsoWithAutoroutePattern = "973p27"
TorsoWithAviatorJacketW_Eagle_Smh_OnBackPattern = "973pq5"
TorsoWithBandageAndGoldNecklacePattern = "973pq0"
TorsoWithBandage_GoldNecklaceAndGoldBeltPattern = "973pq1"
TorsoWithBatmanRobinPattern = "973pb2"
TorsoWithBlackCollarAndPocketsPattern = "973pst"
TorsoWithBlackDiagonalZipAndPocketPattern = "973p0b"
TorsoWithBlackDungareesPattern = "973p1a"
TorsoWithBlackFalconPattern = "973p43"
TorsoWithBlackFuturonPattern = "973p6b"
TorsoWithBlackHalfPattern = "973pbm"
TorsoWithBlackStripePattern = "973px2"
TorsoWithBlackSuit_RedShirt_GoldClaspsPattern = "973pdf"
TorsoWithBlacktronIPattern = "973p52"
TorsoWithBlacktronIiPattern = "973p51"
TorsoWithBlouse_BeltAndNecklacePattern = "973pq6"
TorsoWithBlueCastleBodicePattern = "973p4n"
TorsoWithBlueDungareesPattern = "973p1b"
TorsoWithBlueFlowersOnTiedShirtPattern = "973p2g"
TorsoWithBlueFuturonPattern = "973p6c"
TorsoWithBlueHorizontalStripesPattern = "973p1d"
TorsoWithBlueImperialGuardOfficerPattern = "973p3r"
TorsoWithBlueImperialGuardPattern = "973p3n"
TorsoWithBluePlaidShirtPattern = "973pdd"
TorsoWithBlueShirtAndSafetyStripesPattern = "973p8g"
TorsoWithBlueStripedDungareesPattern = "973p1r"
TorsoWithBlueUndershirtGreenBowAndGunPattern = "973pw5"
TorsoWithBlueV_Neck_PocketsAnd3ButtonsPattern = "973p06"
TorsoWithBlueVest_CollarAndStarPattern = "973par"
TorsoWithBlueVest_CollarAndTestTubePattern = "973pas"
TorsoWithBlueVest_Pockets_ShirtAndDrillPattern = "973pat"
TorsoWithBlueVest_Tools_ShirtAndBombPattern = "973pau"
TorsoWithBlueAndMintGreenStripesPattern = "973p2e"
TorsoWithBomberJacket_BlackShirtPattern = "973p70"
TorsoWithBomberJacket_Belt_BlackShirtPattern = "973pa5"
TorsoWithBrownVest_AscotAndBeltPattern = "973p3b"
TorsoWithBrownVest_BuckleAndStringBowtiePattern = "973pw9"
TorsoWithBusinessSuitAndTie_BreathingApparatusAndOctanLogoPattern = "973p6h"
TorsoWithButtonsAndPoliceBadgePlainPattern = "973p1f"
TorsoWithCard_Suit_Vest_AndGoldFobPattern = "973pw8"
TorsoWithCastleBodiceAndCloakPattern = "973p4h"
TorsoWithCastleBreastplatePattern = "973p40"
TorsoWithCastleChainmailPattern = "973p41"
TorsoWithCastleCrossedPikesPattern = "973p42"
TorsoWithCastleFemaleArmourPattern = "973p4g"
TorsoWithCastleRed_GreyPattern = "973p47"
TorsoWithCatsuit_RingZipperPullAndBeltPattern = "973pb8"
TorsoWithChefJacketWith8ButtonsAndLongRedNeckerchiefPattern = "973p8t"
TorsoWithChefPattern = "973p2a"
TorsoWithClassicSpacePattern = "973p90"
TorsoWithClassicSpaceSimulatedWearPattern = "973p91"
TorsoWithClockworkRobotPattern = "973pc67"
TorsoWithConstructionSafetyVestWithReflectiveStripesPattern = "973p8i"
TorsoWithCorsetWithReddishBrownLacesPattern = "973p4w"
TorsoWithCrewNeckSweaterWithBrightPinkCollarPattern = "973pd17"
TorsoWithCrewNeckSweaterWithCollarAnd_HailToTheChef_OnWhiteApronPattern = "973p89"
TorsoWithCrownOnDarkblue_MediumblueQuartersPattern = "973p4j"
TorsoWithDarkBrownMusclesAndBellyPattern = "973px1"
TorsoWithDarkOrangeVestAndPurpleBowTiePattern = "973pb7"
TorsoWithDarkblueMusclesAndGoldNecklacePattern = "973pq2"
TorsoWithDkGreenCorsetWithLeatherBeltPattern = "973p4x"
TorsoWithDkgray_Black_AndYellowBatmanPattern = "973pb1"
TorsoWithDoctorCoatOverMediumAzureUndershirt_Stethoscope_PocketWithPensPattern = "973p9m"
TorsoWithDragonClaspsAndRedTiesFrontAndDragonBackPattern = "973pnb"
TorsoWithDragonHeadPattern = "973p4b"
TorsoWithDressAndRedBeadsNecklacePattern = "973pd13"
TorsoWithDress_WhiteApronAndRedBeadsNecklace = "973p88"
TorsoWithExplorienLogoPattern = "973p55"
TorsoWithExtremeTeamJacketLogoPattern = "973p8a"
TorsoWithFantasyEraPeasantRopeBeltPattern = "973p4v"
TorsoWithFemaleJumpsuitWithZipper_WhiteAndGoldMarkingsAndClassicSpaceLogoPattern = "973p6g"
TorsoWithFemalePiratePattern = "973p38"
TorsoWithFemaleShirtWithTwoButtonsAndShellPendantPattern = "973p8k"
TorsoWithFemaleWhiteShirt_OpenJacketPattern = "973pae"
TorsoWithFireFighterFiveButtonPattern = "973p21"
TorsoWithForestmanBlackCollarPattern = "973p50"
TorsoWithForestmanBlueCollarPattern = "973p49"
TorsoWithForestmanMaroonCollarPattern = "973p48"
TorsoWithForestmanAndPursePattern = "973p46"
TorsoWithFourButtonSuitAndTrainLogoPattern = "973p84"
TorsoWithFrontAndRearStickersWith_Tine_LogoOnBlueBackground = "973d05"
TorsoWithGoldAsianCharactersFrontAndDragonBackPattern = "973pna"
TorsoWithGoldFobAnd100DollarBillsPattern = "973pwa"
TorsoWithGoldIcePlanetPattern = "973p61"
TorsoWithGoldNecklaceAndYellowUndershirtPattern = "973p72"
TorsoWithGoldTiePinAndBlackTiePattern = "973pd7f"
TorsoWithGreenCastleBodicePattern = "973p4q"
TorsoWithGreenDungareesPattern = "973p1j"
TorsoWithGreenFuturonPattern = "973p6i"
TorsoWithGreenLanternLogoOnWhiteBackgroundAndMusclesOutlinePattern = "973pc0"
TorsoWithGreenStripesAndLeatherStrapPattern = "973p3t"
TorsoWithGreyMusclesAndArcReactorPattern = "973pbh"
TorsoWithGreyAndGoldBatmanPattern = "973pb0"
TorsoWithGryffindorUniformPattern = "973ph1"
TorsoWithHpHarryPotterUniformGryffindorStripeAndShieldPattern = "973pha"
TorsoWithHpNarcissaMalfoyPattern = "973ph9"
TorsoWithHalterTopWithGreenApplesAndLimeSpotsPattern = "973p1x"
TorsoWithHogwartsUniformPattern = "973ph0"
TorsoWithHoodedSweatshirt_BluePocket_DrawstringPatt = "973p7j"
TorsoWithHorseHeadPattern = "973p2m"
TorsoWithHospitalEmtStarOfLife_OpenCollar_ButtonsAndPocketPenPattern = "973p8n"
TorsoWithImperialSoldierPattern = "973p3u"
TorsoWithInsectoidsFemale_BlueDiamondUnderCircuitsPattern = "973p58"
TorsoWithInsectoidsRobotPattern = "973p53"
TorsoWithInsectoidsWithBlueXUnderCircuitsPattern = "973p56"
TorsoWithInsectoidsWithGreenCircuitry_SilverHoseOnSides = "973p6k"
TorsoWithInsectoidsWithSilverCircuitry_LightningBoltsOverBlueCircle = "973p67"
TorsoWithInsectoidsWithSilverLogoOnBlackPanels = "973p57"
TorsoWithInsectoidsWithSilverXOnGreenVerniers = "973p59"
TorsoWithIntegralArms = "17"
TorsoWithIronFistPattern = "973pbq"
TorsoWithIronManArmouredSuitClassicPattern = "973pbt"
TorsoWithIronManArmouredSuitMarkViPattern = "973pbb"
TorsoWithIronManArmouredSuitMarkViiPattern = "973pbc"
TorsoWithIronManArmouredSuitMarkXliiPattern = "973pbf"
TorsoWithIronManArmouredSuitMarkXviiPattern = "973pbe"
TorsoWithIronPatriotArmouredSuitPattern = "973pbg"
TorsoWithIronSpiderPattern = "973pbu"
TorsoWithIvyDressPattern = "973pb5"
TorsoWithJacketAndMediumDarkFleshCollarOverLightBluishGreyShirtPattern = "973p9l"
TorsoWithJacketOverLtBlueButtonDownShirtPattern = "973p7z"
TorsoWithJacketOverMediumBlueSkinAndLightBlueWaistPattern = "973pd1d"
TorsoWithJacketOverShirtAndPrisonStripesPattern = "973p7t"
TorsoWithJacketWithPocketsOverDarkRedV_NeckSweaterPattern = "973p1y"
TorsoWithJacket_BadgeAndRedTiePattern = "973p7r"
TorsoWithJacket_BowTie_Vest_BoutonnierePattern = "973pc23"
TorsoWithJacket_OrangeVest_GreenNeck_ChiefPattern = "973pb3"
TorsoWithJacket_PinkShirt_RingOnNecklacePattern = "973p7h"
TorsoWithJacket_Pocket_Badge_BlueTiePattern = "973p7q"
TorsoWithJacket_TieAndPoliceBadgeYellowStarPattern = "973p76"
TorsoWithJacket_WhiteShirtAndDarkPinkTiePattern = "973pd31"
TorsoWithJacket_WhiteShirt_AndNecklacePattern = "973pa8"
TorsoWithJacket_ZipperedPocketsAndClassicSpaceLogoPattern = "973p6j"
TorsoWithJailStripesAnd_23768_Pattern = "973p7k"
TorsoWithLotrArmor_BrownBelt_GoldBucklePattern = "973pm5"
TorsoWithLotrButtonShirtWithBracesPattern = "973pm2"
TorsoWithLotrCloakWithDarkBluishGreyFoldsPattern = "973pm9"
TorsoWithLotrCloak_RopeAndBeltPattern = "973pm1"
TorsoWithLotrCoat_DarkBluishGreyShirt_EvenstarPendantAndBeltPattern = "973pm7"
TorsoWithLotrJacketAndDarkRedVestPattern = "973pm3"
TorsoWithLotrJacketAndYellowVestPattern = "973pm8"
TorsoWithLotrLeatherArmorWithBucklePattern = "973pm0"
TorsoWithLotrOrcLeatherArmorPattern = "973pma"
TorsoWithLotrScaleArmorAndBeltPattern = "973pm6"
TorsoWithLotrShirt_DarkBrownBelt_BagPattern = "973pm4"
TorsoWithLotrUruk_HaiLurtzMusclesOutlinePattern = "973pmb"
TorsoWithLaunchCommandLogoAndEquipmentPattern = "973p1q"
TorsoWithLeatherJacketPattern = "973p28"
TorsoWithLeatherJacketAndBadgePattern = "973p7u"
TorsoWithLeatherJacketAndLightGrayShirtPattern = "973pa9"
TorsoWithLeatherJacket_SlashPocketsAndWaistbandOverRedShirt_SilverOvalBeltBucklePattern = "973p9e"
TorsoWithLifebeltLogoAndIdCardPattern = "973p79"
TorsoWithLightBlueParabolaShapedBellyPattern = "973pcfd"
TorsoWithLightGreyWaistPattern = "973pd1e"
TorsoWithLionGoldOnBlueShieldPattern = "973p4f"
TorsoWithMbaLevel1LogoPattern = "973pt0"
TorsoWithMbaLevel2LogoPattern = "973pt1"
TorsoWithMtronLogoPattern = "973p68"
TorsoWithMagentaQuestionmarkPattern = "973pb6"
TorsoWithMailHornPattern = "973p1s"
TorsoWithMaroon_RedQuartersShieldPattern = "973p4u"
TorsoWithMayanNecklace_TribalShirt_NavelPattern = "973pac"
TorsoWithMedallion_BeltAndSilverButtonsPattern = "973p3d"
TorsoWithMediumBlueTrimAndFlowersPattern = "973p96"
TorsoWithMetallicSilverRomanSegmentedBodyArmourPattern = "973pc6a"
TorsoWithModernFirefighterPatternType1 = "973p77"
TorsoWithModernFirefighterPatternType2 = "973p78"
TorsoWithNecklaceAndBlueSquaresPattern = "973pwe"
TorsoWithNecklaceAndFringePattern = "973pc11"
TorsoWithNeonYellowStripes_RadioAndBadgePattern = "973p7v"
TorsoWithNinjaWrap_GoldShuriken_AndArmourPattern = "973pn6"
TorsoWithNinjaWrap_GoldShuriken_AndDaggerPattern = "973pn7"
TorsoWithNinjaWrap_SilverShuriken_DaggerPattern = "973pn5"
TorsoWithOctan_Oil_BadgePattern = "973p81"
TorsoWithOctanLogoPattern = "973pt2"
TorsoWithOpenJacketOverStripedVestPattern = "973p34"
TorsoWithOpenJacket_BlueTopAndNavelPattern = "973pd1"
TorsoWithOpenSuitJacketWithWhiteShirt_DarkRedTieAndReddishBrownBeltPattern = "973p9i"
TorsoWithOpenSuitRevealingSupermanLogoPattern = "973pbk"
TorsoWithOrangeDungarees_Sweater_BluePenInPocketPattern = "973p8m"
TorsoWithPalmTreePattern = "973p2h"
TorsoWithPalmTreeAndDolphinPattern = "973p2j"
TorsoWithPalmTreeAndHorsePattern = "973p2k"
TorsoWithPatchPocketPattern = "973p26"
TorsoWithPharaohBreastplatePattern = "973pa2"
TorsoWithPinstripeVest_RedTieAndPocketWatchPattern = "973p9h"
TorsoWithPinstripedJacketAndGoldTiePattern = "973p8l"
TorsoWithPirateCaptainPattern = "973p36"
TorsoWithPirateGreenVest_Shirt_AndBeltPattern = "973p3c"
TorsoWithPirateOpenJacketOverBrownVestPattern = "973p39"
TorsoWithPiratePurpleVestAndAnchorTattooPattern = "973p30"
TorsoWithPirateRaggedShirtAndDaggerPattern = "973p3a"
TorsoWithPirateStripesBlue_CreamPattern = "973p32"
TorsoWithPirateStripesBlue_WhitePattern = "973p3e"
TorsoWithPirateStripesRed_BlackPattern = "973p33"
TorsoWithPirateStripesRed_CreamPattern = "973p31"
TorsoWithPirateVestWith3GoldButtonsOverRedAndWhiteStripedShirtPattern = "973p3g"
TorsoWithPlainShirtWithPocketsPattern = "973p7g"
TorsoWithPoliceFemaleShirtWithGoldBadge_PocketAndBlackTiePattern = "973p7l"
TorsoWithPoliceJacket_SilverBadge_4ButtonsAndBeltPattern = "973pcbf"
TorsoWithPrisonerAnd_50380_Pattern = "973p7s"
TorsoWithPurpleGreatcoatPattern = "973phb"
TorsoWithRes_QOrangePocketsAndLogoPattern = "973p8b"
TorsoWithRacingJacketAndTwoStarsPattern = "973p1h"
TorsoWithRacingJacketAndTwoStarsRedPattern = "973p1n"
TorsoWithRearStickerWhite_1_OnTransparentBackground = "973d06"
TorsoWithRed_GrayShirt_PotBelly_JacketPattern = "973paf"
TorsoWithRedCrossPattern = "973p24"
TorsoWithRedCrossAndStethoscopePattern = "973p25"
TorsoWithRedDungareesPattern = "973p1c"
TorsoWithRedFuturonPattern = "973p6d"
TorsoWithRedHorizontalStripesPattern = "973p1e"
TorsoWithRedImperialGuardOfficerPattern = "973p3s"
TorsoWithRedImperialGuardPattern = "973p3q"
TorsoWithRedNecklaceAndBlueUndershirtPattern = "973p71"
TorsoWithRedShirtAndSuitPattern = "973p22"
TorsoWithRedStrapsAndBelt_YellowClaspsAndCordAndMusclesOutlinePattern = "973pby"
TorsoWithRedTruckPattern = "973p1t"
TorsoWithRedUndershirtAndFringePattern = "973pw7"
TorsoWithRedV_NeckAndButtonsPattern = "973p17"
TorsoWithRedVestAndTrainLogoPattern = "973p82"
TorsoWithRedOnBottomAndFringePattern = "973pwd"
TorsoWithRed_PeachQuartersShieldPattern = "973p4t"
TorsoWithRed_WhiteWaist_ZipperAndWhiteStarPattern = "973pbl"
TorsoWithRidingJacketPattern = "973p12"
TorsoWithRobotPattern = "973p63"
TorsoWithRockRaidersJetPattern = "973paj"
TorsoWithRoyalKnightsLionHead_Neck_ChainPattern = "973p4e"
TorsoWithRoyalKnightsLion_HeadShieldPattern = "973p4d"
TorsoWithRumpledShirt_2RevolversInBeltPattern = "973paa"
TorsoWithSwBenKenobiPattern = "973ps6"
TorsoWithSwBlastArmor_GreenPlates_Bl_GreyPattern = "973prb"
TorsoWithSwBlastArmor_GreenPlates_GreyPattern = "973psb"
TorsoWithSwBlastArmor_SilverPlates_Pattern = "973psj"
TorsoWithSwBlastArmor_UncolouredPlates_Pattern = "973prc"
TorsoWithSwCadBanePattern = "973psw"
TorsoWithSwCamouflageSmockPattern = "973psm"
TorsoWithSwClosedShirtAndBrownBeltPattern = "973pr0"
TorsoWithSwDarkRedRobePattern = "973psx"
TorsoWithSwDarthVaderBluishGreyPattern = "973pra"
TorsoWithSwDarthVaderDeathStarPattern = "973psz"
TorsoWithSwDarthVaderGreyPattern = "973ps7"
TorsoWithSwGreyShirt_BeltWithRedBucklePattern = "973pr7"
TorsoWithSwGunganDarkGrey_DarkTanShirtsPattern = "973pr6"
TorsoWithSwHothTrooperPattern = "973psh"
TorsoWithSwImperialGrandMoffPattern = "973pr9"
TorsoWithSwImperialOfficerPattern = "973psq"
TorsoWithSwImperialShuttlePilotPattern = "973psn"
TorsoWithSwJawaPattern = "973pss"
TorsoWithSwJediRobesAndSashPattern = "973ps2"
TorsoWithSwLayeredShirt_BrownBeltPattern = "973pr3"
TorsoWithSwLayeredShirt_BrownBelt_BraidPattern = "973pr4"
TorsoWithSwLayeredShirt_WaistSashPattern = "973ps8"
TorsoWithSwLeiaHothJacketPattern = "973prd"
TorsoWithSwMoistureFarmerPattern = "973psv"
TorsoWithSwNuteGunrayPattern = "973prh"
TorsoWithSwPocket_VestAndTechno_BucklePattern = "973psc"
TorsoWithSwProtocolDroidPattern = "973psr"
TorsoWithSwRebelA_WingPilotPattern = "973ps0"
TorsoWithSwRebelMechanicPattern = "973psa"
TorsoWithSwRebelPilotBluishGreyPattern = "973pr8"
TorsoWithSwRebelPilotPattern = "973ps1"
TorsoWithSwRobeAndRopeBeltPattern = "973pr2"
TorsoWithSwRobe_SashAndSilverNeckClaspPattern = "973pr1"
TorsoWithSwScoutTrooperBluishGreyPattern = "973pre"
TorsoWithSwScoutTrooperGreyPattern = "973pse"
TorsoWithSwShadowTrooperPattern = "973prk"
TorsoWithSwShirtOpenCollarNoVestPattern = "973ps4"
TorsoWithSwStormtrooperPattern = "973psk"
TorsoWithSwTunicAndBeltPattern = "973psf"
TorsoWithSwVest_WhiteShirt_LtFleshNeckPattern = "973pr5"
TorsoWithSwVest_WhiteShirt_YellowNeckPattern = "973ps5"
TorsoWithSwWrap_AroundTunicPattern = "973ps3"
TorsoWithSafariShirt_BlackNeckAndBrownHolsterPattern = "973pa7"
TorsoWithSafariShirt_BlueTee_RedBandanaPattern = "973pa6"
TorsoWithSafariShirt_Gun_RedBandana_WhiteChestPattern = "973pax"
TorsoWithSafariShirt_Gun_RedBandana_YellowChestPattern = "973pa3"
TorsoWithSafariShirt_TanBandana_CompassPattern = "973pq7"
TorsoWithSafetyVestWithReflectiveStripesOverMediumBlueShirt_IdBadgeAndRedPenAroundNeckPattern = "973p8r"
TorsoWithSamuraiDragonRobePattern = "973pn0"
TorsoWithSamuraiRobe_SashAndDaggerPattern = "973pn1"
TorsoWithScaleMailAndRedDiamondAmuletPattern = "973p4c"
TorsoWithSecurityGuardPattern = "973pb4"
TorsoWithShellLogoPattern = "973p60"
TorsoWithSheriffPattern = "973pw4"
TorsoWithShirtCollarAndSandGreenNeckPattern = "973px0"
TorsoWithShirtWith3FlowersOverYellowAndSilverStripePattern = "973p8y"
TorsoWithShirtWithBlackBellyBumpAndCollarOutlinePattern = "973pd11"
TorsoWithShirtWithCargoLogoPattern = "973p2n"
TorsoWithShirt_Pink_SalmonTieAndIdBadge = "973p87"
TorsoWithSilverArmorFrontAndBackAndDrillPattern = "973pav"
TorsoWithSilverIcePlanetPattern = "973p62"
TorsoWithSilverMetalPlatesAndDarkPinkElectricalWiresAndButtonsPattern = "973pbx"
TorsoWithSilverZodEmblemAndOvalBeltBuckleAndMusclesOutlinePattern = "973pbw"
TorsoWithSixButtonSuitAndAirplanePattern = "973p04"
TorsoWithSixButtonSuitAndAnchorPattern = "973p05"
TorsoWithSixButtonSuit_RedTie_AndAirplanePattern = "973p8u"
TorsoWithSkullAndDkpinkRosesPattern = "973pc00"
TorsoWithSkullAndRedRosesPattern = "973pc44"
TorsoWithSlingshotOnBackPattern = "973pd12"
TorsoWithSlytherinUniformPattern = "973ph2"
TorsoWithSoccerShirt_10_And_Zidane_Pattern = "973pg0"
TorsoWithSoccerTeamGoalkeeperAndWhite_1_Pattern = "973pg1"
TorsoWithSoccerTeamRed_BlueStripesAndRed_2Pattern = "973pg2"
TorsoWithSoccerTeamRed_BlueStripesAndRed_3Pattern = "973pg3"
TorsoWithSoccerTeamRed_BlueStripesAndRed_4Pattern = "973pg4"
TorsoWithSoccerTeamRed_BlueStripesAndRed_7Pattern = "973pg5"
TorsoWithSoccerTeamRed_BlueStripesAndRed_9Pattern = "973pg6"
TorsoWithSoccerTeamRed_BlueStripesAndRed_10Pattern = "973pg7"
TorsoWithSoccerTeamRed_BlueStripesAndRed_11Pattern = "973pg8"
TorsoWithSoccerTeamRed_BlueStripesAndRed_18Pattern = "973pg9"
TorsoWithSoccerTeamWhiteStripesAndWhite_2Pattern = "973pga"
TorsoWithSoccerTeamWhiteStripesAndWhite_3Pattern = "973pgb"
TorsoWithSoccerTeamWhiteStripesAndWhite_4Pattern = "973pgc"
TorsoWithSoccerTeamWhiteStripesAndWhite_7Pattern = "973pgd"
TorsoWithSoccerTeamWhiteStripesAndWhite_9Pattern = "973pge"
TorsoWithSoccerTeamWhiteStripesAndWhite_10Pattern = "973pgf"
TorsoWithSoccerTeamWhiteStripesAndWhite_11Pattern = "973pgg"
TorsoWithSoccerTeamWhiteStripesAndWhite_18Pattern = "973pgh"
TorsoWithSpacePoliceIiChiefPattern = "973p6a"
TorsoWithSpacePoliceIiAndRadioPattern = "973p69"
TorsoWithSpacePortLogo_TubeAnd_C1_Pattern = "973p8e"
TorsoWithSpacesuitWithFrontStrap_BadgesAndPortsPattern = "973p5b"
TorsoWithSpiderManPattern = "973pbv"
TorsoWithSpider_GirlPattern = "973pbp"
TorsoWithSpottedSingletAndNecklacePattern = "973p2f"
TorsoWithSpyriusPattern = "973p66"
TorsoWithStethoscopeAndPocketWithPensPattern = "973p86"
TorsoWithStickerShellLogoOnWhiteBackground = "973d04"
TorsoWithStraightZipperJacketPattern = "973p13"
TorsoWithStraplessSuntopPattern = "973p2c"
TorsoWithStripedShirtAndSilverButtonsPattern = "973p3f"
TorsoWithStuddedArmourPattern = "973p45"
TorsoWithStudiosDirectorPattern = "973pd0"
TorsoWithSuitAndRedTieWithTrainLogoPattern = "973p83"
TorsoWithSuitAndTiePattern = "973p18"
TorsoWithSuitWithPocket_RedTie_TrainPattern = "973p8h"
TorsoWithSupermanLogoAndDarkBlueMusclesPattern = "973pb9"
TorsoWithSuspendersAndRedBowtiePattern = "973pa1"
TorsoWithSweaterV_NeckOverLightBlueShirtPattern = "973p94"
TorsoWithSweaterWithDarkAzureShirtWithCollarAndOrangeAscotTiePattern = "973px3"
TorsoWithT_ShirtWith4WhiteHorizontalStripesFrontAndBackWithCatPattern = "973p9n"
TorsoWithT_Shirt_BlueDungareesAndToolsPattern = "973p8z"
TorsoWithTvLogoPatternLarge = "973p1m"
TorsoWithTvLogoPatternSmall = "973p1k"
TorsoWithTankTop_Braces_YellowSkinPattern = "973pq4"
TorsoWithTankTop_Stains_Wrench_AndTattooPattern = "973pab"
TorsoWithTelephonePattern = "973p8f"
TorsoWithThreeWhiteAndSilverSquaresPattern = "973p8x"
TorsoWithTownVestWithPocketsAndStripedTiePattern = "973p8j"
TorsoWithTrainLogoAndRedDiagonalStripesPattern = "973p19"
TorsoWithTri_ColouredShieldLargePattern = "973p4r"
TorsoWithTri_ColouredShieldAndGoldTrimPattern = "973p4s"
TorsoWithUfoAlienCircuitryAndRedLeverPattern = "973p6w"
TorsoWithUfoAlienInsigniaAnd3BlueBarsPattern = "973p6v"
TorsoWithUfoAlienOrangeAndSilverPattern = "973p54"
TorsoWithUfoAlienSilverAndGoldCircuitryPattern = "973p6x"
TorsoWithUfoAlienTriangularInsigniaPattern = "973p6u"
TorsoWithUsCavalryGeneralPattern = "973pw1"
TorsoWithUsCavalryOfficerPattern = "973pw2"
TorsoWithUsCavalrySoldierPattern = "973pw3"
TorsoWithUnitronPattern = "973p64"
TorsoWithV_NeckShirtAndBlueOverallsPattern = "973p7w"
TorsoWithVerticalRedStripesAnd_Clutchers_Pattern = "973pc3g"
TorsoWithVerticalStripedBlue_RedPattern = "973p02"
TorsoWithVerticalStripedRed_BluePattern = "973p01"
TorsoWithVestWithPatchPocketsPattern = "973p73"
TorsoWithVest_PatchPocketsAndPoliceBadgeYellowStarPattern = "973p74"
TorsoWithVest_SlingshotInBeltPattern = "973pad"
TorsoWithVoldemortRobePattern = "973ph3"
TorsoWithWaistcoat_WhiteShirtAndBandolierPattern = "973pq3"
TorsoWithWaiterPattern = "973p20"
TorsoWithWarMachineArmouredSuitPattern = "973pbd"
TorsoWithWhiteBracesAndCartridgeBeltPattern = "973pw6"
TorsoWithWhiteButtonsAndPoliceBadgePlainSticker = "973d03"
TorsoWithWhiteDiagonalZipAndPocketPattern = "973p0a"
TorsoWithWhiteEnvelopeAndZipperPattern = "973p7x"
TorsoWithWhiteOrcaBellyPattern = "973pd6e"
TorsoWithWhiteRope_PatchedCollarPattern = "973pdg"
TorsoWithWhiteScarfAndBrownBeltPattern = "973pay"
TorsoWithWhiteShirtAndJacketPattern = "973p03"
TorsoWithWhiteShirtWithDarkBlueTie_GoldAirlinePin_BeltAndIdBadgePattern = "973p8w"
TorsoWithWhiteSuit_BrownVestAndTiePattern = "973pa4"
TorsoWithWhiteTigerPattern = "973pbr"
TorsoWithWhiteVerticalStripesAndRedBowTiePattern = "973p7i"
TorsoWithWhite_RedArmourAndWhiteBelt = "973pwf"
TorsoWithWhite_Yellow_OrangeRacesuitPattern = "973p95"
TorsoWithWindsurfboardPattern = "973p2d"
TorsoWithWolfpackPattern = "973p44"
TorsoWithYellowButtonsAndGreyBeltSticker = "973d02"
TorsoWithYellowChestAndWhiteBeadsNecklacePattern = "973pd14"
TorsoWithYellowFuturonPattern = "973p6e"
TorsoWithZipperJacketAnd3PocketsPattern = "973p1u"
TorsoWithZipperJacketAndPoliceLogoPattern = "973p75"
TorsoWithZipperAndPoliceBadgePlainPattern = "973p1g"
