# coding=utf-8
"""
library/parts.py - Auto-generated Part classes for the Python ldraw package.

Copyright (C) 2018 Matthieu Berthomé <rienafairefr@gmail.com>

This file is part of the ldraw Python package.

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.


<< This file is auto-generated, you shouldn't have to modify it>>
"""
# pylint: disable=invalid-name, line-too-long, too-many-lines

AcousticGuitar = "25975"
AcousticGuitarWithBlackFingerboardAndNeckAndMetallicSilverStringsPattern = "25975p01"
AcousticGuitarWithBlackTuningPegsAndMetallicSilverStringsPattern = "25975p02"
Airtanks = "3838"
ArmorSamurai = "30174"
ArmorShoulderPadsWith1StudOnFront_2StudsOnBack = "11097"
ArmorShoulderPadsWithNeckProtection_1StudOnFront_2StudsOnBack = "15086"
ArmorShoulderPadsWithRidges = "11438"
ArmourPlate = "2587"
ArmourPlateWithLotrKingTheodenPattern = "2587pm0"
ArmourSwCloneTrooperPauldron = "61190b"
ArmourSwCloneTrooperTasset = "61190c"
ArmourShoulder_NeedsWork_ = "30121"
ArrowQuiver = "4498"
Axe = "95330"
AxeWithTwin_Blade = "95052"
BabyBody = "25126"
BabyBodyWithBodysuit = "15526"
BabyBodyWithYellowHandsPattern = "25126p01"
BabyBodyWithYellowHandsAndBibWithElephantPattern = "25126p02"
BackpackNon_Opening = "2524"
BackpackOpenableClosed = "30158c01"
BackpackOpenableOpen = "30158"
BackpackSkydiver = "12897"
BackpackWithHorizontalPinHoles = "15406"
BackpackWithSleepingBag = "30323"
Bandana = "30133"
BarWithBatWings = "98721"
BarbedWireLoop = "62700"
Basketball = "43702"
BasketballNetForHoop = "43374"
BasketballWithBlackSpokesPattern = "43702p01"
BatWing = "98722"
Battleaxe = "3848"
BattleaxeBlade = "53454"
BeardLongForked = "60750"
BeardLongWithFiveBraids = "60749"
BeardMediumShort = "93223"
BeardShort = "15501"
BeardWithRoundedEnd = "10052"
Bicycle_Complete_ = "4719c01"
BicycleFrame = "4719"
BicycleWithIntegralTyreWheels = "4719c03"
BinocularsWithRoundEyepiece = "30162"
BladedClawSpread = "10187"
Book = "33009-f1"
BookBaseWithTwoStuds = "24324"
BookCover = "24093"
BookCoverWithDisneyCastleAndGoldTrimPattern = "24093p01"
BookOpen = "33009-f2"
BookWithBookCoverMoriaChroniclesStickers = "33009dm0"
Bottle1X1X2Cylindrical = "95228"
Bottle1X1X2CylindricalWithBottleShipPattern = "95228p01"
BowWithArrow = "4499"
BreastplateWithFinsAndEmbossedAtlantisTriangle = "89917"
Broom = "4332"
Bugle = "71342"
CameraMovie = "30148"
CameraSnapshotType1 = "30089a"
CameraSnapshotType2 = "30089b"
CameraWithSideSight = "4360"
CandleFlame = "37775"
Cannon2X4Base = "2527"
Cannon2X8Non_Shooting = "518"
CannonNon_ShootingWithBase_Shortcut_ = "2527c01"
CannonShooting_Complete_ = "2533c01"
CannonShootingBarrelAndBreech = "2535c01"
CapAviator = "30171"
CapAviatorGoggles = "30170"
CapAviatorWithBlackGoggles = "30171c01"
CapWithLongFlatPeak = "4485"
CapWithShortArchedPeak = "86035"
CapWithShortArchedPeakAndBlackHeadphones_EarProtection = "11303c01"
CapWithShortArchedPeakWithSeamsAndTopPinHole = "11303"
Cape = "4524"
CapeCloth = "50231"
CapeCloth_FormedFloating_ = "50231c02"
CapeCloth_Formed_ = "50231c01"
CapeClothScalloped5Points = "56630"
CapeClothScalloped5Points_Formed_ = "56630c01"
CapeClothShort = "99464"
CapeClothShort_Formed_ = "99464c01"
CapeClothWithHolesAndTatteredEdges = "86038"
CapeClothWithHolesAndTatteredEdges_Formed_ = "86038c01"
CapeClothWithInsideDarkRedPattern_Formed_ = "50231p01c01"
CapeClothWithPointedEndsAndCollar = "42450"
CapeClothWithPointedEndsAndCollar_Formed_ = "42450c01"
CastleHelmetWithChin_Guard = "3896"
CastleHelmetWithNeckProtector = "3844"
Cauldron = "4341"
Chain6LWith6LSpanCatenary = "92338-f2"
Chain6LWith6LSpanStraight = "92338-f1"
Chain16LWith16LSpanStraight = "60169"
Chain17LWith17LSpanStraight = "30104"
ChainEndForChain6LAnd17L = "30104k01"
ChainEndForChain16L = "60169k01"
ChainLinkForChain6LAnd17L = "30104k02"
ChainLinkForChain16L = "60169k02"
ChainsawBlade = "6117"
CheerleaderPomPom = "87997"
CheerleaderPomPomWithBluePattern = "87997p01"
CheerleaderPomPomWithRedPattern = "87997p02"
CircularBladeSaw = "30194"
Cleaver = "98369"
ClothWrap_BandanaWithRoundedTop = "18927"
CoinWith_1_GothicType = "96904"
CoinWith_2_GothicType = "96905"
CoinWith_5_GothicType = "96906"
CoinWith_10_GothicType = "96907"
CoinWith_10_Sans_SerifType = "70501a"
CoinWith_20_Sans_SerifType = "70501b"
CoinWith_30_Sans_SerifType = "70501c"
CoinWith_40_Sans_SerifType = "70501d"
Comb = "30112b"
Compass_Complete_ = "889c01"
ComputerLaptop_Closed_ = "62698-f3"
ComputerLaptop_OpenFlat_ = "62698-f1"
ComputerLaptop_Open_ = "62698-f2"
ConicalFlask = "u9180"
ConicalFlaskTransclearWithColouredBase = "u9180c01"
ConstructionHelmet = "3833"
ConstructionHelmetWithHairShort = "16175"
ConstructionHelmetWithMediumDarkFleshHairShortPattern = "16175p02"
ConstructionHelmetWithReddishBrownHairShortPattern = "16175p01"
ContainerD_Basket = "4523"
Crossbow = "2570"
CrownTiara = "33322"
CrownTiaraFlatWithArchedBottom = "96491"
CrownWithBar0_5L = "25516"
Cup = "3899"
CupTakeaway = "15496"
CupWithBarHandle = "38014"
Dagger = "88288"
DaggerWithPearlLightGrayBlade = "88288p01"
DinnerPlate = "6256"
DiverMask = "30090"
DynamiteSticksBundle = "64728"
EagleWing = "93250"
EagleWingWithTanFeathersAndRed_GoldPattern = "93250pq0"
ElectricGuitar = "93564"
ElectricGuitarClassic = "11640"
ElectricGuitarWithBlackStrings_DkpinkLightningPattern = "93564p02"
ElectricGuitarWithSilverStrings_WhiteBodyPattern = "93564p01"
Epaulette = "2526"
FeatheredHeaddressSmall = "87696"
FeathersWithClip = "30127"
FeathersWithClipAndBlackTipPattern = "30127p01"
FeathersWithPin = "30126"
FeathersWithPinAndBlackTipOnOneSidePattern = "30126p02"
FeathersWithPinAndBlackTipOnBothSidesPattern = "30126p01"
FeathersWithPinAndRedTipWithBlackStripePattern = "30126p03"
FireHelmet = "3834"
FireHelmetBreathingHose = "6158"
FireHelmetWithFireLogoShieldPattern = "3834p01"
Flame7LWithBar0_8 = "85959"
Flame7LWithBar0_8WithMarbledTransBrightGreenFlameTipPattern = "85959p05"
Flame7LWithBar0_8WithMarbledTransClearFlameTipPattern = "85959p04"
Flame7LWithBar0_8WithMarbledTransGreenFlameTipPattern = "85959p03"
Flame7LWithBar0_8WithMarbledTransOrange_TransYellowFlameTipPattern = "85959p01"
Flame7LWithBar0_8WithMarbledTransPurpleFlameTipPattern = "85959p06"
Flame7LWithBar0_8WithMarbledTransYellowFlameTipPattern = "85959p02"
FlameWithPegs = "6126a"
FlameWithRim = "6126b"
Flipper = "2599"
FlippersOnSprue = "2599c01"
FoodApple = "33051"
FoodBanana = "33085"
FoodBreadBun = "25386"
FoodCarrot = "33172"
FoodCarrotTop = "33183"
FoodCarrotWithBright_GreenLeaves_Complete_ = "33172c02"
FoodCarrotWithGreenLeaves_Complete_ = "33172c01"
FoodCherry = "22667"
FoodCroissant = "33125"
FoodFrenchBread = "4342"
FoodIceCreamCone = "33120"
FoodIceCreamScoops = "6254"
FoodPieWithCreamFilling = "93568"
FoodPieWithWhiteCreamFillingPattern = "93568p01"
FoodPieWithYellowCreamFillingPattern = "93568p02"
FoodPopsicle = "30222"
FoodPretzel = "10170"
FoodSausage = "33078"
FoodTurkeyBody = "33048"
FoodTurkeyWithLegs_Complete_ = "33048c01"
ForestmanCap = "4506"
ForestmanCapWithSmallRedPlume_Complete_ = "4506c01"
Frypan = "4528"
GhostShroud = "2588"
Goblet = "2343"
GobletWithHollowStem = "6269"
Gollum = "10057"
GollumWithNarrowEyesAndHalf_OpenMouthPattern = "10057pm1"
GollumWithWideEyesAndOpenMouthPattern = "10057pm0"
GrapplingHookWithBar = "15534"
GunBlasterWithStudsOnSides_BottomAndFront = "44709"
GunFlintlockPistol = "2562"
GunLaserKryptonian = "13952"
GunLaserPistol = "87993"
GunLongBlaster = "57899"
GunMusket = "2561"
GunPistolTwoBarrel = "95199"
GunRevolver = "30132"
GunRifle = "30141"
GunSwSmallBlasterDc_17 = "61190a"
GunSemiautomaticPistol = "55707a"
GunShootingBlaster = "15391"
GunShootingBlasterTrigger = "15392"
GunShootingBlasterWithDarkBluishGreyTrigger = "15391c01"
GunShootingBlasterWithDarkBluishGreyTriggerAndTransOrangeProjectile = "15391c02"
GunShortBlaster = "58247"
GunSmallBlasterWithTelescopicSight = "92738"
HairBackslick = "64798"
HairBeard = "6132"
HairBubbleStyle_Afro_ = "87995"
HairCoiled = "21778"
HairCombedFrontToRear = "92081"
HairFemaleLongStraightWithLeftSideParting = "92083"
HairFemalePonytailWithLongFrenchBraid = "88286"
HairFemaleShortSweptSideways = "20877"
HairFemaleWithElaborateKnotBun = "13251"
HairFemaleWithPigtails = "3625"
HairFlatTop = "30608"
HairIslander = "6025"
HairLongStraight = "40239"
HairLongTousledWithCentreParting = "20595"
HairLongWavy = "40251"
HairLongAndHalfBraided_NeedsWork_ = "30475"
HairLongWithCurls = "11255"
HairLongWithFrenchBraid = "59363"
HairLongWithHeadband = "30114"
HairLongWithHeadbandAndFeathers_Complete_ = "30114c01"
HairLongWithOneFrontLock = "85974"
HairMale = "3901"
HairMid_LengthTousledWithCentreParting = "88283"
HairMohawk = "93563"
HairObiWan = "61196"
HairOrcWithDarkTanEarsPattern = "10066p01"
HairOrcWithEars = "10066"
HairOrcWithMediumDarkFleshEarsPattern = "10066p02"
HairOrcWithOliveGreenEarsPattern = "10066p03"
HairPeaked = "42444"
HairPonytail = "6093a"
HairPonytailOff_Centre = "15427"
HairPonytailOff_CentreWithMagentaStripePattern = "15427p02"
HairPonytailOff_CentreWithMagentaAndMediumAzureStripesPattern = "15427p01"
HairPonytailWithLongBangs = "62696"
HairPulledBack = "92756"
HairRockerWithSideburns = "98371"
HairShortBobCut = "62711"
HairShortBowlCut = "40240"
HairShortCombedSidewaysWithLeftParting = "99930"
HairShortSweptBackWithSideburnsAndWidow_SPeak = "21268"
HairShortTousled = "40233"
HairShortWavyWithCentreParting = "26139"
HairShort_TousledWithSideParting = "62810"
HairShort_WavyWithSidePart = "11256"
HairShoulderLength = "4530"
HairSpiked = "98385"
HairSpikyLong = "53982"
HairSpikyShort = "53981"
HairStraightCutWithShortPonytail = "17630"
HairSweptBackIntoBun = "99240"
HairSweptBackTousled = "61183"
HairSweptBackWithWidow_SPeak_Chin_LengthAndBushyInBack = "21269"
HairSweptLeftTousled = "23186"
HairSweptRightWithFrontCurl = "98726"
HairTousled = "10048"
HairTousledAndLayered = "92746"
HairTousledWithSideParting = "87991"
HairWavy = "43751"
HairWavyWindblownToOneSide = "32602"
HairWith2LocksOnLeftSide = "15443"
HairWithSnakes = "12889"
HairWithTwoBuns = "30409"
HairbrushWithLongHandle = "3852a"
HairbrushWithShortHandle = "3852b"
Handcuffs = "61482"
Handlebars = "30031"
HandlebarsWithAngularHandles = "98397"
Harpoon = "57467"
HarpoonWithSmoothBar = "18041"
HeaddressAnubisGuard = "93248"
HeaddressAnubisGuardW_GoldEyeAndStripesPattern = "93248pq0"
HeaddressAztecBird = "99243"
HeaddressAztecBirdWithEyesAndCheeksPattern = "99243p01"
HeaddressBatman = "55704"
HeaddressCatwoman = "98729"
HeaddressCatwomanShortWithWiderApartEyeholes = "55705"
HeaddressHorus = "93249"
HeaddressHorusWithEyePattern = "93249pq0"
HeaddressIndianBuffaloHorned = "30113"
HeaddressIndianWarbonnet = "30138"
HeaddressIndianWarbonnetWithColouredFeathersPattern = "30138p01"
HeaddressNemesType1 = "30168b"
HeaddressNemesType2 = "90462b"
HeaddressNemesWith2DarkblueSnakesPattern = "90462bpq0"
HeaddressNemesWithDarkblueStripesPattern = "90462bpq1"
HeaddressSwZabrakHorns = "92761"
HeaddressTurban = "40235"
HeaddressWerewolf = "42443"
HeaddressWithHookedBeakAndFeathers = "30276"
Headphones_EarProtection = "14045"
HelmetAlienSkullWithFangs = "85945"
HelmetArmy = "87998"
HelmetArmyWithWhiteStencilCrossPattern = "87998p01"
HelmetBubbleHalf = "61287"
HelmetCap = "60748"
HelmetCapWithWings = "60747"
HelmetCastleRohanWithCheekProtection_Comb = "10054"
HelmetCastleRohanWithCheekProtection_CombWithEomerPattern = "10054p01"
HelmetCastleRohanWithCheekProtection_CombWithTheodenPattern = "10054p02"
HelmetCastleUruk_HaiWithLateralComb = "10051"
HelmetCastleW_DragonCrownTopBlackW_DragonPlume = "6122c01"
HelmetCastleW_DragonCrownTopW_CattlehornWhite = "6122c02"
HelmetCastleWithAngledCheekProtection = "48493"
HelmetCastleWithDragonCrownTop = "6122"
HelmetCastleWithFixedFaceGrille = "4503"
HelmetClassicWithCrackedThinChinGuard = "16599"
HelmetClassicWithThickChinGuardAndVisorDimples = "3842b"
HelmetClassicWithThinChinGuardAndVisorDimples = "3842a"
HelmetDarthVader = "30368"
HelmetGladiator = "95676"
HelmetImperialAt_StPilot = "57900"
HelmetIronMan = "10907"
HelmetIronManWithVisorWithGoldFace_WhiteEyesPattern = "10907c01"
HelmetMining = "30325"
HelmetModern = "2446"
HelmetModernWithBlack_BlueAndSilverUnitronPattern = "2446p51"
HelmetModernWithBlueAndSilverSpyriusPattern = "2446p50"
HelmetModernWithOneRedAndTwoGreenStripesPattern = "2446p01"
HelmetMorion = "30048"
HelmetPersian = "88284"
HelmetRangefinderForSwCloneTrooperHelmet = "63586"
HelmetRomanSoldier = "98366"
HelmetSwRebelPilotWithCheckeredPattern = "30370ps4"
HelmetSwRebelPilotWithYellowGridOnBluishgreyPattern = "30370ps1"
HelmetSwRebelPilotWithYellowGridOnGreyPattern = "30370ps5"
HelmetSamurai = "30175"
HelmetSamuraiHorn = "529"
HelmetSamuraiWithHorn_Complete_ = "30175c01"
HelmetScoutTrooper = "30369"
HelmetSkateboard = "46303"
HelmetStarWarsRebelPilot = "30370"
HelmetStarWarsRebelPilotWithBlueRebelLogoPattern = "30370ps3"
HelmetStarWarsRebelPilotWithRedRebelLogoPattern = "30370ps2"
HelmetStormtrooper = "30408"
HelmetStormtrooperWithStormtrooperPattern = "30408p01"
HelmetStormtrooperWithTie_FighterPilotPattern = "30408p02"
HelmetUnderwater = "87754"
HelmetVikingHorn = "53451"
HelmetVikingWithNoseProtector = "53450"
HelmetVikingWithWhiteHorns_Complete_ = "53450c01"
HelmetVisor = "2447"
HelmetVisorIcePlanet = "6119"
HelmetVisorIronMan = "10908"
HelmetVisorIronManWithGoldFace_BlueEyesPattern = "10908p02"
HelmetVisorIronManWithGoldFace_WhiteEyesPattern = "10908p01"
HelmetVisorIronManWithSilverFaceAndDkredLinePattern = "10908p04"
HelmetVisorIronManWithSilverFace_WhiteEyesPattern = "10908p03"
HelmetVisorLargeWithTrapezoidAreaOnTop = "89159"
HelmetVisorSpace = "769"
HelmetVisorUnderwater = "6090"
HelmetVisorWithGrilleAndFeather = "3843"
HelmetWelding = "13792"
HelmetWeldingWithDarkBlueStripesOnBlackVisorPattern = "13792p01"
HelmetWithBatWings = "30105"
HelmetWithChinstrapAndWideBrim = "30273"
HelmetWithFrontProngs = "10305"
HelmetWithFrontProngsWithDarkPurpleHighlightPattern = "10305p01"
HelmetWithHexagonalTopAndGoldAlienPattern = "30120p01"
HelmetWithHexagonalTopAndHoses = "30120"
HelmetWithHexagonalTopAndSilverAlienPattern = "30120p02"
Hips = "3815b"
HipsAndLegs = "73200-f1"
HipsAndLegsShortWithHole = "41879b"
HipsAndLegsShortWithHorizontalStripe = "16709"
HipsAndLegsShortWithYellowHorizontalStripePattern = "16709p01"
HipsAndLegsShortWithYellowHorizontalStripeAndSlingshotOnBackPattern = "16709p02"
HipsAndLegsShortWithoutHole = "41879a"
HipsAndLegsWithBeltAndReflectiveStripes_Emmet_BadgePattern = "3815c8h"
HipsAndLegsWithBeltAndReflectiveStripes_Emmet_BadgeAndSilverTrianglesOnFeetPattern = "3815c8i"
HipsAndLegsWithBlue_WhiteTriangles_FringePattern = "3815cw2"
HipsAndLegsWithButtonedPocketsPattern = "3815ca3"
HipsAndLegsWithClockworkRobotPattern = "3815cc67"
HipsAndLegsWithDarkGreyBelt_DarkRedLoincloth_WhiteClaws_FurTailPattern = "3815caw"
HipsAndLegsWithDarkTurquoise_WhiteTriangles_WhiteFringePattern = "3815cw3"
HipsAndLegsWithDarkblueLoinclothPattern = "3815cq0"
HipsAndLegsWithDecoratedLoinclothPattern = "3815cq1"
HipsAndLegsWithDkblue_GoldLoinclothPattern = "3815cq2"
HipsAndLegsWithGoldCircuitryPattern = "3815c6w"
HipsAndLegsWithGrassSkirtPattern = "3815c3j"
HipsAndLegsWithGreenKilt_ToesPattern = "3815ca2"
HipsAndLegsWithHarlequinRed_BlackPattern = "3815cba"
HipsAndLegsWithHolsterAndBeltPattern = "3815ca9"
HipsAndLegsWithIronManArmouredSuitMarkViPattern = "3815cbb"
HipsAndLegsWithIronManArmouredSuitMarkViiPattern = "3815cbc"
HipsAndLegsWithIronManArmouredSuitMarkXliiPattern = "3815cbf"
HipsAndLegsWithIronManArmouredSuitMarkXviiPattern = "3815cbe"
HipsAndLegsWithIronPatriotArmouredSuitPattern = "3815cbg"
HipsAndLegsWithLotrCoat_ShirttailsAndBeltPattern = "3815cm2"
HipsAndLegsWithLotrLeatherArmorPattern = "3815cm0"
HipsAndLegsWithLotrScaleArmourPattern = "3815cm1"
HipsAndLegsWithLaboratorySmockPattern = "3815cde"
HipsAndLegsWithLeatherArmourPattern = "3815c4f"
HipsAndLegsWithOrangeCablePattern = "3815c6u"
HipsAndLegsWithPurpleGreatcoatPattern = "3815chb"
HipsAndLegsWithRedRomanTunicAndBeltPattern = "3815cc6a"
HipsAndLegsWithRed_WhiteTriangles_FringePattern = "3815cw1"
HipsAndLegsWithRobotPattern = "3815c63"
HipsAndLegsWithSwGunbeltPattern = "3815cs5"
HipsAndLegsWithSwStormtrooperPattern = "3815csk"
HipsAndLegsWithSalmonCablePattern = "3815c6v"
HipsAndLegsWithStuddedBeltAndSafetyPinsPattern = "3815cc44"
HipsAndLegsWithWarMachineArmouredSuitPattern = "3815cbd"
HipsAndLegsWithWhiteApronPattern = "3815c89"
HipsAndLegsWithWhiteAndGoldMarkingsPattern = "3815c6g"
HipsAndLegsWithWoodenLeg = "3815c36"
HipsAndLegs_Sitting = "73200-f2"
HipsWithBlackBeltWithSilverBeltBucklePattern = "3815p8i"
HipsWithClockworkRobotPattern = "3815pc67"
HipsWithDarkGreyBeltWithSilverBuckleAndRivetsPattern = "3815paw"
HipsWithGoldBeltAndDarkblueLoinclothPattern = "3815pq0"
HipsWithGoldBeltAndOrangeCablePattern = "3815p6u"
HipsWithGoldO_BeltAndLoinclothPattern = "3815pq2"
HipsWithGoldX_BeltAndDecoratedLoinclothPattern = "3815pq1"
HipsWithHarlequinBlackSquarePattern = "3815pba"
HipsWithHolsterAndBeltPattern = "3815pa9"
HipsWithIronManArmouredSuitMarkXliiPattern = "3815pbf"
HipsWithIronManArmouredSuitMarkXviiPattern = "3815pbe"
HipsWithIronPatriotArmouredSuitPattern = "3815pbg"
HipsWithLotrCoat_ShirttailsAndBeltPattern = "3815pm2"
HipsWithLotrDarkRedBelt_ScaleArmorPattern = "3815pm1"
HipsWithLotrLeatherArmorPattern = "3815pm0"
HipsWithLaboratorySmockPattern = "3815pde"
HipsWithLeatherBelt_RedStuds_Pattern = "3815p4f"
HipsWithPurpleGreatcoatPattern = "3815phb"
HipsWithRedRomanTunicAndBeltPattern = "3815pc6a"
HipsWithRedTiedSashPattern = "3815bpc1"
HipsWithRed_WhiteTrianglesPattern = "3815pw1"
HipsWithRobotPattern = "3815p63"
HipsWithSwGunbeltPattern = "3815ps5"
HipsWithSwStormtrooperPattern = "3815psk"
HipsWithSilverBeltPattern = "3815p6w"
HipsWithSilverBeltAndSalmonCablePattern = "3815p6v"
HipsWithStuddedBeltPattern = "3815pc44"
HipsWithTentacles = "87749"
HipsWithWarMachineArmouredSuitPattern = "3815pbd"
HipsWithWhiteApronPattern = "3815p89"
HipsWithWhiteAndGoldMarkingsPattern = "3815p6g"
HockeyStickWith1_1LBar = "93559"
Hood = "30381"
HoodFur_Lined = "30287"
HoodFur_LinedWithWhiteFurTrimPattern = "30287p01"
HoodMedievalCowl = "4505a"
HoseNozzleWithSideStringHole = "58367"
HoseNozzleWithSideStringHoleSimplified = "60849"
Hoverboard = "21271"
IceAxe = "30193"
IceAxeWith3_RibHandle = "18738"
Jackhammer = "30228"
Jester_SCap = "62537"
Jester_SCapWithBlackHalfAndWhitePomsPattern = "62537p02"
Jester_SCapWithBlueHalfAndBluePomPattern = "62537p01"
Jester_SCapWithRedHalfAndRedPomPattern = "62537p03"
JetPackWith2OctagonalNozzles_NeedsWork_ = "6023"
Jet_PackWithStudOnFront = "4736"
Key = "62808"
Knife = "44658"
KnifeWithFlatHiltEnd = "95054"
KnifesOnSprue = "44658c01"
Ladle = "4337"
Lance = "3849"
Lantern = "37776"
Lasso = "99253"
LegsOld = "15"
LifeRing = "30340"
LifeguardFloat = "90395"
Lifevest = "2610"
Lightning = "59233"
LightsaberChromeSilver_1SideOn = "577bc01"
LightsaberChromeSilver_2SidesOn = "577bc02"
LightsaberHiltShortCurved = "61199"
LightsaberHiltWithBend = "42114"
LightsaberHiltWithBottomRing = "577b"
LightsaberHiltWithoutBottomRing = "577a"
LightsaberWithBendChromeSilver_1SideOn = "42114c01"
LightsaberWithBendChromeSilver_2SidesOn = "42114c02"
LongBowWithArrow = "93231"
Loudhailer = "4349"
LoudhailerWithOrangeStripePattern = "4349p01"
Machete = "29109"
MachineGunWithDrumMagazine = "55707b"
MagicWand = "6124"
Maracas = "90508"
MaracasWithGreenBorderPattern = "90508p01"
Martian_Complete_ = "30529c01"
MartianLegs = "30530"
MaskWolf = "11233"
MaskWolfWithFangs_ScarsAndWhiteEarsPattern = "11233p01"
MechanicalLegs = "30376"
MechanicalSwBattleDroid_Shortcut_ = "30375cs0"
MechanicalSwBattleDroidCommander_Shortcut_ = "30375cs1"
MechanicalSwBattleDroidPilot_Shortcut_ = "30375cs3"
MechanicalSwBattleDroidSecurity_Shortcut_ = "30375cs2"
MechanicalShoulderWithTwoBar_Holes = "22392"
Megaphone = "39144"
MetalDetector = "4479a"
Microphone = "90370"
MicrophoneWithMetallicSilverTop = "90370p01"
Mop = "24085"
Moustache = "15439"
Mug = "33054"
NinjaWrap = "30177"
OilLamp = "98383"
PaintBrush = "93552"
PaintBrushWithSilverRingAndGreenTipPattern = "93552p01"
PaintPalette = "93551"
PaintPaletteWithPaintDropsPattern = "93551p01"
PaintRollerBrushHandle = "12885"
Pharaoh_SStaffWithForkedEnd = "93252"
Pickaxe = "3841"
PipeWrench_NeedsWork_ = "4328"
Pitchfork = "4496"
PlumeDragon = "87687"
PlumeDragonWingLeft = "87685"
PlumeDragonWingRight = "87686"
PlumeHorsetailWithBar0_5L = "22411"
PlumeLarge = "87694"
PlumeSmall = "87693"
PlumeTriple = "87692"
Plume_FlameTriple = "64647"
Plunger = "11459"
PlungerWithMediumDarkFleshHandle = "11459p01"
PolearmHalberd = "6123"
PoliceHelmet = "13789"
PoliceHelmetWithSilverBadgePattern = "13789p01"
PotSmallWithHandleHolders = "98374"
PropellorWithBatWings = "55707e"
Pushbroom = "3836"
RadioWithLongHandle = "3962b"
RadioWithShortHandle = "3962a"
RiceBowl = "34172"
Ring1X1 = "11010"
RingWithTriangle = "87748"
RingWithTriangleWithGoldBandsAndCrabPattern = "87748p01"
RingWithTriangleWithGoldBandsAndMantaRayPattern = "87748p05"
RingWithTriangleWithGoldBandsAndSharkPattern = "87748p03"
RingWithTriangleWithGoldBandsAndSquidPattern = "87748p04"
RingWithTriangleWithGoldBandsAndTrianglePattern = "87748p06"
RingWithTriangleWithGoldBandsAndTurtlePattern = "87748p02"
RollerSkate = "11253"
RussianFurCap = "43894"
Sack = "92590"
Satchel = "61976"
Saucepan = "4529"
SaucerWithHollowStudOnTop = "38799"
Saxophone = "13808"
SaxophoneWithBlackMouthpiece = "13808p01"
ScabbardForTwoSwords = "88290"
ScabbardForTwoSwordsWithBar = "19141"
Scooter = "15396c01"
ScooterBody = "15396"
ScooterWithRider = "15396c02"
ScubaTank = "30091"
Seat2X2 = "4079"
ServingTray2X3 = "29635"
Sextant = "30154"
Shackles = "55707d"
ShieldBroadWithSpikedBottomAndCutoutCorner = "10049"
ShieldOctagonalWithStud = "48494"
ShieldOctagonalWithTrollSkullOnDarkRedPattern = "61856p40"
ShieldOctagonalWithoutStud = "61856"
ShieldOval = "92747"
ShieldOvalWithSwGunganPatrolShieldPattern = "92747p01"
ShieldOvoid = "2586"
ShieldOvoidW_CrownOnDark_MedBlueQuartersPattern = "2586p4j"
ShieldOvoidW_DkgreenDragonOnMddkflesh_TanPattern = "2586p4k"
ShieldOvoidWithAmericanIndianPattern = "2586pw1"
ShieldOvoidWithBatPattern = "2586p4f"
ShieldOvoidWithBlueDragonPattern = "2586p4c"
ShieldOvoidWithGallopingHorseAndFeathersPattern = "2586pw2"
ShieldOvoidWithGoldLionOnRed_WhiteQuart_Pattern = "2586p4l"
ShieldOvoidWithGoldenLionPattern = "2586ph1"
ShieldOvoidWithGreenDragonPattern = "2586p4b"
ShieldOvoidWithIndigoIslandersPattern = "2586p30"
ShieldOvoidWithRoyalKnightsLionPattern = "2586p4d"
ShieldOvoidWithSwGunganPatrolShieldPattern = "2586ps1"
ShieldOvoidWithSilverSkullOnDarkRedPattern = "2586p4h"
ShieldOvoidWithSilverSnakePattern = "2586ph2"
ShieldPentagonalCastellated = "22408"
ShieldPentagonalJagged = "22409"
ShieldRectangularCurvedWithStud = "98367"
ShieldRound = "3876"
ShieldRoundBowed = "75902"
ShieldRoundBowedWithBullseyeWithStarPattern = "75902p02"
ShieldRoundBowedWithDkgreenAndGoldRohanPattern = "75902p01"
ShieldRoundBowedWithGoldEaglePattern = "75902p03"
ShieldRoundBowedWithMercedes_BenzLogo = "75902p04"
ShieldRoundBowedWithSwDejarikHologameBoardPattern = "75902ps1"
ShieldRoundFlat = "59231"
ShieldRoundFlatWithHelmetOnDark_MediumBlueQuartersPattern = "59231p40"
ShieldRoundFlatWithSilverSkullOnDarkRedPattern = "59231p4h"
ShieldRoundType2 = "91884"
ShieldRoundType2WithAztecBirdOnDarkRedPattern = "91884p04"
ShieldRoundType2WithDarkBrownRingAnd4RivetsPattern = "91884p01"
ShieldRoundType2WithDragonHeadsAndOrnamentsPattern = "91884p03"
ShieldRoundType2WithSilverRivetsPattern = "91884p02"
ShieldScarab = "93251"
ShieldTriangular = "3846"
ShieldTriangularLong = "18836"
ShieldTriangularLongWithBlackPyramidAndSunPattern = "18836pq0"
ShieldTriangularW_CrownOnDk_MedBlueQuart_Pattern = "3846p4j"
ShieldTriangularW_GoldLionOnRed_WhiteQuart_Patt_ = "3846p4l"
ShieldTriangularW_WhiteMalteseCrossOnRedSticker = "3846d02"
ShieldTriangularW_YellowTrefoilsOnDkblueSticker = "3846d07"
ShieldTriangularWithBatPattern = "3846p4f"
ShieldTriangularWithBlackFalconBlueBorderPattern = "3846p45"
ShieldTriangularWithBlackFalconYellowBorderPattern = "3846p46"
ShieldTriangularWithBlueDragonPattern = "3846p4c"
ShieldTriangularWithBlueLionOnYellowPattern = "3846p4g"
ShieldTriangularWithCrownOnDark_PinkSticker = "3846d01"
ShieldTriangularWithCrownOnVioletSticker = "3846d05"
ShieldTriangularWithDragonOnMddkflesh_TanPattern = "3846p4k"
ShieldTriangularWithForestmanPattern = "3846p48"
ShieldTriangularWithGreenChevronsOnYellowSticker = "3846d03"
ShieldTriangularWithGreenChevronsOnYellow_Ltgray = "3846d06"
ShieldTriangularWithLionHead_Blue_YellowPattern = "3846p4e"
ShieldTriangularWithMaroon_RedQuartersPattern = "3846p4u"
ShieldTriangularWithRedCrossAndHelmetPattern = "3846p01"
ShieldTriangularWithRedInBlueFramePattern = "3846p47"
ShieldTriangularWithRed_PeachQuartersPattern = "3846p4t"
ShieldTriangularWithRoyalKnightsLionPattern = "3846p4d"
ShieldTriangularWithWolfpackPattern = "3846p44"
ShieldTriangularWithYellowLionOnBluePattern = "3846p4h"
ShieldTriangularWithYellowTrefoilsOnBlueSticker = "3846d04"
Shovel = "3837"
SignalHolder = "3900"
SignalHolderWithBlack_Police_AndRedLinePattern = "3900p01"
SignalHolderWithGreenCircleOnWhiteSticker = "3900d01"
Skate = "93555"
SkateboardWithBlackWheels_Complete_ = "42511c01"
SkateboardWithFourWheelClips = "42511"
SkateboardWithTwoWheelClips = "45917"
Skeleton_Shortcut_ = "6260c01"
Ski4LWithHinge = "6120"
Ski4LWithoutHinge = "99774"
Ski6L = "90509"
SkiPole = "90540"
Skirt = "36036"
Skirt0_7LWith11DiamondPoints = "16820"
Skirt0_7LWith11DiamondPoints_Formed_ = "16820c01"
Skirt1_1LWithStraightBottom = "600880"
Skirt1_1LWithStraightBottom_Formed_ = "600880c01"
Skirt1_1LWithStraightBottomWithDarkGreenApronPattern = "600880p01"
Skirt1_1LWithStraightBottomWithDarkGreenApronPattern_Formed_ = "600880p01c01"
Skirt1_4LWithStraightBottom = "u9209"
Skirt1_4LWithStraightBottom_Formed_ = "u9209c01"
Skirt1_4LWithStraightBottomWithWhiteApronWithLacePattern = "u9209p01"
Skirt1_4LWithStraightBottomWithWhiteApronWithLacePattern_Formed_ = "u9209p01c01"
Skirt1_5LFringed = "14295"
Skirt1_5LFringed_Formed_ = "14295c01"
Skirt1_5LFringedWithSteppedEdge = "18200"
Skirt1_5LFringedWithSteppedEdge_Formed_ = "18200c01"
Sledgehammer = "75904"
Slingshot = "20546"
SlingshotWithBrightLightYellowBandPattern = "20546p02"
SlingshotWithDarkTanBandPattern = "20546p01"
SmallBowWithArrow = "95051"
Snowboard2X6 = "18746"
Snowshoe = "30284"
SoccerBall = "72824"
SoccerBallWithBlackPentagonsPattern = "72824p01"
SpaceScannerTool = "30035"
Spear = "4497"
SpearTipFacetedWithBar0_4L = "27257"
SpearWithFourSideBlades = "43899"
Speargun = "30088"
StaffWithCrescentEnd = "95050"
StaffWithSphericalEnd = "95049"
Statuette = "90398"
SteakOnBone = "98372"
SteakOnBoneWithRedMeatPattern = "98372p01"
StretcherWithBottomHinges = "4714"
StretcherWithoutBottomHinges = "93140"
Suitcase_Closed_ = "4449-f1"
Suitcase_Open_ = "4449-f2"
SuitcaseWithIronManArmouredSuitMarkVStickers = "4449-f1d01"
SurfBoard2X6_5 = "90397"
SurfBoard2X6_5WithPinkFlamesPattern = "90397p02"
SurfBoard2X6_5WithWhiteShark_BlackOpenMouthAndGillsPattern = "90397p05"
SurfBoard2X10 = "6075"
SwordCutlass = "2530"
SwordDoubleBladeSerratedWithBarHolder = "13549"
SwordGreatsword = "59"
SwordKatana_DragonGuard_ = "93055"
SwordKatanaType1_OctagonalGuard_ = "30173a"
SwordKatanaType2_SquareGuard_ = "30173b"
SwordKatanaType3_SquareGuardWithSmoothEndcap_ = "21459"
SwordKhopesh = "93247"
SwordLongsword = "98370"
SwordRapier = "93550"
SwordRomanGladius = "95673"
SwordSaberWithClipPommel = "59229"
SwordScabbardWithShoulderStrap = "95348"
SwordScimitar = "43887"
SwordScimitarWithJaggedEdge = "60752"
SwordShortsword = "3847"
SwordShortswordWithElaborateHilt = "76764"
SwordSmallWithAngularGuard = "95053"
SwordSmallWithCurvedBlade = "10053"
SwordUruk_Hai = "10050"
SwordWithAngularHilt = "48495"
Syringe = "87989"
TeddyBearWithArmsDown = "98382"
TeddyBearWithArmsDownWithTanBellyAndMuzzleAndBlackNoseAndEyesPattern = "98382p01"
Telescope = "64644"
TennisRacket = "93216"
TomahawkWithFlat_SilverBlade = "13571"
Tool4_WayLugWrench = "604553"
ToolAdjustableWrenchWith3_RibHandle = "604614"
ToolBatteryPoweredDrill = "604549"
ToolBinocularsSpace = "30304"
ToolBoxWrench = "55300"
ToolBoxWrenchWith3_RibHandle = "604552"
ToolCrowbar = "92585"
ToolFishingRod = "2614"
ToolGrapplingHook = "30192"
ToolHammer = "55295"
ToolHammerWith3_RibHandle = "604547"
ToolHandaxe = "3835"
ToolHolder = "2516"
ToolHoseNozzleWithHandle = "4210a"
ToolMagnifyingGlass = "30152"
ToolMallet = "4522"
ToolOar = "2542"
ToolOarReinforced = "87585"
ToolOilcan = "55296"
ToolOilcanWithRibbedHandle = "604548"
ToolOpenEndWrench = "55299"
ToolOpenEndWrenchWith3_RibHandle = "604551"
ToolPowerDrill = "55297"
ToolScissors = "18920"
ToolScrewdriver = "55298"
ToolSocketWrenchWithRatchetAnd3_RibHandle = "604615"
ToolSpanner_Screwdriver = "4006"
ToolWand = "36752a"
ToolWandSprue = "36752b"
ToolWandsOnSprue = "36752c01"
Toolbox1X3WithHandle = "98368"
Torch = "3959"
TorchWithoutGrooves = "86208"
ToyWinderKey = "98375"
TrayOval = "11252"
TrophyCup2_4L = "10172"
TrophyCup3_6L = "89801"
TrophyCup5L = "72092"
Umbrella = "4094b"
UmbrellaFolded = "27150"
UnderwaterScooter = "30092"
UtilityBelt = "27145"
Vest = "3840"
VestWithCrownOnDarkPinkSticker = "3840d01"
VestWithCrownOnVioletSticker = "3840d05"
VestWithGreenChevronsOnYellowSticker = "3840d03"
VestWithGreenChevronsOnYellow_LtgreySticker = "3840d07"
VestWithWhiteMalteseCrossOnRedSticker = "3840d02"
VestWithWhiteMalteseCrossOnRed_LtgreySticker = "3840d06"
VestWithYellowTrefoilsOnBlueSticker = "3840d04"
VestWithYellowTrefoilsOnDkblueSticker = "3840d08"
WeaponBillyClub = "13790"
WeaponBladedClaw = "88811"
WeaponClubWithSpikes = "88001"
WeaponCrescentBladeSerratedWithBar0_5L = "98141"
WeaponCurvedBlade8_5LWithBar1_5L = "98137"
WeaponTrident = "92290"
WeldingGasTorchWithHoseAndGasCylinderTop = "13793"
Whip = "2488"
WhipBentFlexible = "88704"
WhipCoiled = "61975"
WhipInLatchedPosition = "2488c01"
WineGlass = "33061"
ZipLineHandle_NeedsWork_ = "30229"
