# coding=utf-8
"""
library/parts.py - Auto-generated Part classes for the Python ldraw package.

Copyright (C) 2018 Matthieu Berthomé <rienafairefr@gmail.com>

This file is part of the ldraw Python package.

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.


<< This file is auto-generated, you shouldn't have to modify it>>
"""
# pylint: disable=invalid-name, line-too-long, too-many-lines

AxeWithRedHeadAndSilverBladePattern = "95330p01"
BabyHead = "24581"
BabyHeadWithEyesAndSmilePattern = "24581p01"
BabyWithHeadWithEyesAndSmilePattern = "25126p01c01"
HeadAlienFemaleWithRedEyesAndDarkBluishGreyLipsAndWrinkles_OpenSmileWithMissingToothPattern = "3626cpce8"
HeadAlienSquidman = "85947"
HeadAlienSquidmanWithBlackEyes_LinesPattern = "85947p01"
HeadAlienWithLowerFangs_SingleOrangeEyeOpen_EyeHalfClosed2_SidedPattern = "3626bpc94"
HeadBlackEyeMaskWithWhiteEyeHolesAndDarkBrownCheekLinesPattern = "3626cpd8k"
HeadBlackEyebrows_Freckles_Smile_Worried2_SidedPattern = "3626cp8s"
HeadBlackEyebrows_WhitePupils_Scared_LopsideSmile2_SidedPattern = "3626cp8w"
HeadBlackHeadbandWithWhiteBatmanEyes_BroadSmileShowingTeethPattern = "3626cpd85"
HeadBlackStandardEyes_SmilingWithTongue_StandardGrin2_SidedPattern = "3626cp8e"
HeadBrightPinkHeadbandWithWhiteSquintedBatmanEyesPattern = "3626cpd63"
HeadBrownEyebrows_Freckles_OpenSmilePattern_HollowStudWithPiercedBase_ = "3626bp8b"
HeadBrownEyebrows_Freckles_OpenSmilePattern_HollowStud_ = "3626cp8b"
HeadCuboid = "19729"
HeadCuboidWithMinecraftPumpkinPattern = "19729p01"
HeadCuboidWithMinecraftStevePattern = "19729p02"
HeadElf = "43745"
HeadElfWithGreenEyesPattern = "43745p01"
HeadEwok = "64805"
HeadFemaleBlackEyebrows_Eyelashes_Freckles_PinkLips_LopsidedSmile_Determined2_SidedPattern = "3626cp8d"
HeadFemaleRobotWithRedEyesAndLips_4MetallicSilverMouthSquares_BlackBeautyMark_EyelashesAndHeadsetPattern = "3626cpd2b"
HeadFemaleWithBalaclava_MediumDarkFleshFace_BeautyMarkAndCrookedSmilePattern = "3626cpd89"
HeadFemaleWithBlackEyeMask_DarkRedLipsAndRedDiamondBeautyMark_WinkAndOpenMouth_LickingLips2_SidedPattern = "3626cpd81"
HeadFemaleWithBlackEyeMask_DarkRedLips_RedTongueAndDiamondOnCheek_OpenSmileWithTopTeethPattern = "3626cpd6d"
HeadFemaleWithBlackEyebrowsAndEyelashes_BeautyMarkUnderLeftEye_DarkRedLipsPattern = "3626cpd66"
HeadFemaleWithBlackEyebrowsAndEyesWithEyelash_BroadGrinPattern = "3626cpd8e"
HeadFemaleWithBlackEyebrows_BeautyMark_SingleEyelash_DarkTanLipsAndCrookedSmile_Scowl2_SidedPattern = "3626cpna"
HeadFemaleWithBlackEyebrows_PeachLips_OpenSmileWithTeeth_Sleeping2_SidedPattern = "3626cp8r"
HeadFemaleWithBlackEyebrows_PinkLips_Eyelashes_SunglassesWithMediumLavenderFrames2_SidedPattern = "3626cp8x"
HeadFemaleWithBlackEyebrows_WideEyelashesWithThickDarkAzureMascara_SmileAndDarkOrangeLipsPattern = "3626bpc5e"
HeadFemaleWithBlackEyes_ThinEyebrowsAndRedNarrowLips = "3626bpc42"
HeadFemaleWithBlackAndSilverSunglasses_BlackEyebrows_PeachLipsPattern_HollowStud = "3626cp8v"
HeadFemaleWithBrownEyebrows_MediumDarkFleshLipsAndBrownBeautyMarkOnLeftSidePattern = "3626cpd6h"
HeadFemaleWithBrownEyebrows_PeachLips_PensiveSmile_Scared2_SidedPattern = "3626cp8q"
HeadFemaleWithBrownEyebrows_Pupils_EyelashesPattern = "3626bp09"
HeadFemaleWithGlassesWithDarkGreenFrames_RedLips_Smiling_SmilingWithTeeth2_SidedPattern = "3626cpx2"
HeadFemaleWithGlassesWithGoldFrames_PeachLips_Smiling_SmilingWithTeeth2_SidedPattern = "3626cpx1"
HeadFemaleWithJaggedDarkAzureEyebrows_WhiteAtSidesOfEyes_SilverLipsPattern = "3626cpcg1"
HeadFemaleWithLargeRoundGlassesWithBrightLightBlueLensesAndBlackFrames_OrangeLipsWithSlightCrookedSmilePattern = "3626cpd7i"
HeadFemaleWithMagentaEyeMask_DarkRedLips_GrinWithTeeth_Neutral2_SidedPattern = "3626cpd6a"
HeadFemaleWithMediumDarkFleshGlasses_LaughLines_RedLips_Neutral_RaisedEyebrowsAmused2_SidedPattern = "3626cp8u"
HeadFemaleWithNose_RedLips_AndLargeEyesPattern = "3626bpw3"
HeadFemaleWithRedLipsAnnoyed_Smiling2_SidedPattern_HollowStudWithPiercedBase_ = "3626bp89"
HeadFemaleWithRedLipsAnnoyed_Smiling2_SidedPattern_HollowStud_ = "3626cp89"
HeadFemaleWithRedLipsSmallEyebrowsPattern = "3626bp08"
HeadFemaleWithSilverGlassesAndPinkLipsSmilingPattern = "3626cp8l"
HeadFemaleWithSmiling_Scared2_SidedPattern = "3626bpq3"
HeadFemaleWithThinBlackEyebrows_WhiteEyeShadow_OrangeLipsAndThreeBlackStripesOnCheeksPattern = "3626cpce9"
HeadFemaleWithWhiteSkiGogglesWithPinkAndPurpleGlassAndBlackStrapAndRedLipsPattern = "3626bpc87"
HeadGlasses_ThinBrownEyebrows_SmilePattern_HollowStudWithPiercedBase_ = "3626bp87"
HeadGlasses_ThinBrownEyebrows_SmilePattern_HollowStud_ = "3626cp87"
HeadGoblin = "42109"
HeadGrin_BrownBeard_WhitePupilsPattern_HollowStudWithPiercedBase_ = "3626bp88"
HeadGrin_BrownBeard_WhitePupilsPattern_HollowStud_ = "3626cp88"
HeadLeftyMouthAndStubblePattern = "3626bp81"
HeadMummyFaceWith2Eyes_1Eye2_SidedPattern = "3626bpq0"
HeadMummyWith2Eyes_GoldDeathMask2_SidedPattern = "3626bpq1"
HeadNautolan = "57901"
HeadNautolan_BlackEyes_Mouth_BrownTentacleBands = "57901p01"
HeadOpenSmileWithTeeth_Eyebrows_Scared2_SidedPattern = "3626cp8j"
HeadPeachLips_Smile_BlackEyebrowsPattern_HollowStudWithPiercedBase_ = "3626bp8c"
HeadPeachLips_Smile_BlackEyebrowsPattern_HollowStud_ = "3626cp8c"
HeadProtocolDroid = "30480"
HeadProtocolDroidWithLightYellowEyesPattern = "30480ps0"
HeadReddishBrownHeadbandWithSquintedBatmanEyes_SadMouthPattern = "3626cpd64"
HeadRobot = "98384"
HeadRobotWithBlueEyesAndRed_YellowTeethDisplay = "98384p01"
HeadRobotWithRedEyesAnd4BlackOutlinedSquaresMouthOnSilverBackgroundWithBlackRivetsPattern = "3626cp8p"
HeadRobotWithRedEyes_MetalEyebrowsWithRivets_BrokenWhiteTeethAndStubbleBoltsPattern = "3626cpd2e"
HeadRobotWithRedVisorAnd4BlackOutlinedSquaresMouthOnSilverBackgroundPattern = "3626cp8o"
HeadRobotWithRedVisorAnd9BlackSquaresMouthPattern = "3626cp8n"
HeadRodianWithEyesAndNosePattern = "47545p01"
HeadRodianWithoutPattern = "47545"
HeadSwJawa_YellowEyesWithOrangeRimPattern = "3626cps0"
HeadSimpsonsBartSimpson = "15523"
HeadSimpsonsBartSimpsonWithEyesLookingLeftPattern = "15523p01"
HeadSimpsonsBartSimpsonWithEyesPattern = "15523p02"
HeadSimpsonsHomerSimpson = "15527"
HeadSimpsonsHomerSimpsonWithHalfClosedEyesPattern = "15527p01"
HeadSimpsonsHomerSimpsonWithWideOpenEyesPattern = "15527p02"
HeadSimpsonsLisaSimpson = "15524"
HeadSimpsonsLisaSimpsonWithEyesPattern = "15524p02"
HeadSimpsonsLisaSimpsonWithWorriedEyesPattern = "15524p01"
HeadSimpsonsMargeSimpson = "15522"
HeadSimpsonsMargeSimpsonWithEyesLookingRightPattern = "15522p01"
HeadSimpsonsMargeSimpsonWithWideOpenEyesPattern = "15522p02"
HeadSimpsonsNedFlanders = "15529"
HeadSimpsonsNedFlandersWithGlasses_HairAndMoustachePattern = "15529p01"
HeadSkullCrackedWithMetalPlatesPattern = "3626cpn2"
HeadSpongebob = "54872"
HeadSpongebobWithHappyPattern = "54872p01"
HeadSpongebobWithShockedPattern = "54872p02"
HeadSpongebobWithSuperHeroPattern = "54872p09"
HeadSpongebobOctopus = "64767"
HeadSpongebobStarfish = "54873"
HeadTrandoshan = "87570"
HeadWhiteBushyEyebrows_Goatee_Wrinkles_Smile_OpenMouthScared2_SidedPattern = "3626cp8t"
HeadWookieeWithBandolier = "30483"
HeadWookieeWithSilverBandolier_BlackNosePattern = "30483p01"
HeadYodaWithCurvedEars = "41880"
HeadW_BigEyes_CurvedEyebrows_OrangeMouthPattern = "3626bpao"
HeadWithAdventurersMummyPattern = "3626bpa2"
HeadWithAngryEyebrowsAndTenseMouthPattern = "3626bp0f"
HeadWithAngryMoustacheAndTeethPattern = "3626bpw2"
HeadWithAngryMoustache_WhiteTeethAndGoldToothPattern = "3626bpw0"
HeadWithBalaclavaWithBlackEyeMaskWithWhiteEyeOpeningsAndLightFleshFaceAndScowlPattern = "3626cpbx"
HeadWithBalaclavaWithBlackEyesAndCurledEyelash_Z_InBlackCircle_LightFleshMouthHoleWithSneerPattern = "3626cpd6f"
HeadWithBalaclavaWithBlackSeamsAndWhiteEyesWithLightFleshLowerFacePattern = "3626cpd8c"
HeadWithBalaclavaWithWhiteFrowningEyesAndLightFleshMouthHole_ReddishBrownCheekLines_OpenSmileWithTeethPattern = "3626cpd6i"
HeadWithBeardStubble_Eyebrows_Smile_ScarPattern = "3626cpq0"
HeadWithBeard_Happy_Angry2_SidedPattern = "3626cpbb"
HeadWithBeard_Sneering_Scared2_SidedPattern = "3626cpbh"
HeadWithBlackBushyEyebrows_Smile_Angry2_SidedPattern = "3626cpnf"
HeadWithBlackEyebrowsAndCheekLines2_SidedPattern = "3626cpb9"
HeadWithBlackEyebrowsAndDarkBrownCheekLines_FirmExpressionPattern = "3626cpd8f"
HeadWithBlackEyebrows_BlackAndWhiteGoatee_WrinklesAndCheekLines_Neutral_Angry2_SidedPattern = "3626cpbm"
HeadWithBlackEyebrows_ChinDimpleAndLopsidedGrinPattern = "3626cp8i"
HeadWithBlackEyebrows_MediumDarkFleshCheekLines_DarkTanChinOrnamentAndSadLookPattern = "3626cpd6j"
HeadWithBlackEyebrows_ReddishBrownDimples_LopsidedOpenMouthGrinPattern = "3626cpd69"
HeadWithBlackEyebrows_WhitePupils_ChinDimple_OpenMouthSmileWithTeethPattern = "3626cp73"
HeadWithBlackFullBeard_ThickBlackEyebrowsAndWhitePupilsPattern = "3626bpq5"
HeadWithBlackHair_EyebrowsAndSmirkPattern = "3626bp0d"
HeadWithBlackMaskAndWhiteEyeHolesAndContourLinesPattern = "3626cpd6b"
HeadWithBlackMask_BlueEyesAndBlackLipsPattern = "3626bpba"
HeadWithBlackMoustache_BeardAndMessyHairPattern = "3626bp44"
HeadWithBlack_SilverSunglasses_BlackEyebrows_ChinDimpleAndGrimMouthPattern = "3626cp8z"
HeadWithBlueHeadbandAndDarkOrangeHairPattern = "3626bp66"
HeadWithBlueSunglassesPattern = "3626bp7b"
HeadWithBlueSunglassesAndStubblePattern = "3626bp7e"
HeadWithBlueWrap_AroundSunglassesPattern = "3626bp7c"
HeadWithBrightLightBlueGlassesWithBlackSquaredFrame_Smile_ScreamingOpenMouth2_SidedPattern = "3626cp8m"
HeadWithBrownAngularBeardAndGlassesPattern = "3626bp8d"
HeadWithBrownBushyMoustacheAndEyebrowsAndBlackChinStrapPattern = "3626cpcbe"
HeadWithBrownEyebrows_FleshCheekLines_Smile_SmileWithTeeth2_SidedPattern = "3626cpx5"
HeadWithBrownEyebrows_OpenLopsidedGrinAndWhitePupilsPattern_HollowStud_ = "3626cp8k"
HeadWithBrownEyebrows_SmirkingFace_PupilsPattern = "3626bp83"
HeadWithBrownEyebrows_WhitePupils_LopsidedSmileWithDimplePattern = "3626bp0g"
HeadWithBrownHairOverEyeAndBlackEyebrowsPattern = "3626bp7a"
HeadWithBrownHair_Eyelashes_AndLipstickPattern = "3626bpa6"
HeadWithBrownMoustache_Stubble_Eyebrows_FrowningPattern = "3626bp3r"
HeadWithClosedHollowStud = "3626c"
HeadWithDarkBluishGreyAroundEyesAndOpenMouthLopsidedPattern = "3626cpce7"
HeadWithDarkOrangeBeard_GoldTeethAndEyepatchPattern = "3626cp30"
HeadWithDarkOrangeMoustache_BeardAndMessyHairPattern = "3626bp42"
HeadWithDarkRedLips_Smirk_Eyemask2_SidedPattern = "3626bpb8"
HeadWithDarkredLips_Open_ClosedMouth_Freckles2_SidedPattern = "3626cpbj"
HeadWithEvilSkeletonSkullPattern = "3626bpa8"
HeadWithEyePatch_BlackStubbleAndMessyHairPattern = "3626bp49"
HeadWithEyePatch_DarkOrangeMoustache_BeardAndMessyHairPattern = "3626bp46"
HeadWithEyePatch_DarkOrangeStubbleAndMessyHairPattern = "3626bp48"
HeadWithEyePatch_RedMoustache_BeardAndMessyHairPattern = "3626bp47"
HeadWithEyebrows_Cheeklines_DeterminedPattern = "3626bpc6a"
HeadWithEyebrows_Crow_SFeet_OpenMouthSmile_QueasyExpressionWithSweatDrop2_SidedPattern = "3626cp70"
HeadWithEyeglassesAndLightningScarPattern = "3626bph1"
HeadWithEyesInMask_White_A_AndBlackLineOnBackPattern = "3626cpbl"
HeadWithFreckleNoseAndStandardGrinPattern = "3626bp07"
HeadWithFullBlackBeardWithSideBurns_WhitePupils_OpenMouthGrimacePattern = "3626cpx4"
HeadWithGlassesRounded_BrownEyebrowsAndSmilePattern = "3626cp8y"
HeadWithGlassesAndWhiteMuttonchopsPattern = "3626bpa1"
HeadWithGlasses_BrownSideburnsAndMoustachePattern = "3626bpq4"
HeadWithGlasses_GreyEyebrows_BeardAndMoustachePattern = "3626bp0e"
HeadWithGlasses_GreyEyes_Eyebrows_CheeksPattern = "3626cpbk"
HeadWithGlasses_PencilBehindEarAndPointedMoustachePattern = "3626bpw8"
HeadWithGoldPaintAndSlantedEyesPattern = "3626bp6u"
HeadWithGoldRobotPattern = "3626bp64"
HeadWithGreenBrainAndYellowMouthPattern = "3626bp6y"
HeadWithGreenEyebrows_MediumBlueEyeshadow_ThickRedLipsSmileWithSharpTooth_VerySadFrown2_SidedPattern = "3626cpd68"
HeadWithGreenLipsAndRedEyebrowsPattern = "3626bpb5"
HeadWithGregoryGoyle_HarryPotter2_SidedPattern = "3626bph4"
HeadWithGreyHair_Beard_Moustache_AngryPattern = "3626bp0a"
HeadWithGrin_DarkGreyBeardAndEyebrowsPattern = "3626bp39"
HeadWithGrumpy_Angry2_SidedPattern = "3626cpbd"
HeadWithHpHarryPotterWithGlassesAndLightningBolt_Smile_Frown2_SidedPattern = "3626bph7"
HeadWithHpNarcissaMalfoyWithDarkBrownEyebrows_Crow_SFeet_Angry_Smile2_SidedPattern = "3626bph9"
HeadWithHpRubeusHagridWithWrinklesPattern = "3626bph8"
HeadWithHpVoldemortWithTeethAndNostrilsPattern = "3626bph6"
HeadWithHalf_MoonGlassesAndGreyEyebrowsPattern = "3626bpha"
HeadWithHeadsetOverBrownHairAndEyebrowsPattern = "3626bp69"
HeadWithHollowStud = "3626b"
HeadWithIcePlanetFemaleRedHairPattern = "3626bp65"
HeadWithIcePlanetMessyWhiteHair = "3626bp62"
HeadWithIcePlanetMoustacheAndEyebrowsPattern = "3626bp61"
HeadWithInsectoidsRobotPattern = "3626bp50"
HeadWithIronManArmouredSuitClassicPattern = "3626cpb4"
HeadWithIronSpiderPattern = "3626cpb3"
HeadWithIslanderWhite_BluePaintedFacePattern = "3626bp3k"
HeadWithIslanderWhite_RedPaintedFacePattern = "3626bp3j"
HeadWithLotrDarkbrownBeard_StubbleAndStern_ClenchedTeeth2_SidedPattern = "3626cpm7"
HeadWithLotrFrowning_Grimacing2_SidedPattern = "3626cpm6"
HeadWithLotrFrowning_Scared2_SidedPattern = "3626cpm4"
HeadWithLotrFrowning_Shouting2_SidedPattern = "3626cpm5"
HeadWithLotrOrcWithGreyHairPattern = "3626bpma"
HeadWithLotrSmirking_Shouting2_SidedPattern = "3626cpm8"
HeadWithLotrThickGrayEyebrowsAndSmilePattern = "3626cpm1"
HeadWithLotrTired_Poisoned2_SidedPattern = "3626cpm3"
HeadWithLotrUruk_HaiLurtzScowlAndWhiteHand2_SidedPattern = "3626bpmb"
HeadWithLotrUruk_HaiScowlAndWhiteHand2_SidedPattern_HollowStudWithPiercedBase_ = "3626bpm0"
HeadWithLotrUruk_HaiScowlAndWhiteHand2_SidedPattern_HollowStud_ = "3626cpm0"
HeadWithLotrWorried_Smile2_SidedPattern = "3626cpm2"
HeadWithLargeBlackOpenMouthWithUvulaAndRedTonguePattern = "3626cpd6e"
HeadWithLargeBlueMaskPattern = "3626bp6v"
HeadWithLargeGlassesWithDarkGreyEyebrows_MoustacheAndStubblesAndDarkBrownCheekLinesPattern = "3626cpd67"
HeadWithLightTurquoiseAndOrangePaintedFacePattern = "3626bpw7"
HeadWithMaskBr_GreenWithEyeholesAndSmilePattern = "3626bpb2"
HeadWithMaskPurpleWithEyeholesAndSmilePattern = "3626bpb6"
HeadWithMediumAzureZigzagLinePattern = "3626cpcfb"
HeadWithMessyHairFemalePattern = "3626bp40"
HeadWithMessyHair_MoustacheAndStubblePattern = "3626bp35"
HeadWithMonocleAndBlackSlantedEyebrowsPattern = "3626bpb7"
HeadWithMonocle_Scar_AndMoustachePattern = "3626bpa7"
HeadWithMoustacheCurlyAndSpikyBeardUnderMouthPattern = "3626bp45"
HeadWithMoustache_StubbleAndBaldHairPartPattern = "3626bpw9"
HeadWithMouthClosedStern_MouthOpenScared2_SidedPattern = "3626cp80"
HeadWithOpenSmilingMouth_TeethAndToungePattern = "3626bpc44"
HeadWithOrangeBeardAndWhiteSmilePattern = "3626bp80"
HeadWithOrangePaintedFacePattern = "3626bpw4"
HeadWithPaintedTrianglesPattern = "3626bpw5"
HeadWithPursedLipsAndWhiteForeheadPattern = "3626bpb1"
HeadWithRaisedLeftEyebrow_FrecklesAndCrookedSmilePattern = "3626cp71"
HeadWithRedLipsAndBlackUpsweptEyelashesPattern = "3626bp6f"
HeadWithRedMoustacheAndGoateePattern = "3626bp41"
HeadWithRedMoustache_BeardAndMessyHairPattern = "3626bp43"
HeadWithRedAndDark_TurquoisePaintedLines_Eyebrows_Pupils_NosePattern = "3626bpw6"
HeadWithReddishBrownEyebrowsAndFreckles_LopsidedGrin_FrownPattern2_SidedPattern = "3626cpne"
HeadWithReddishBrownEyebrows_MediumDarkFleshScar_WhiteBand_Aid_LopsidedGrinWithTeeth_Determined2_SidedPattern = "3626cpnb"
HeadWithRonWeasleyPattern = "3626bph3"
HeadWithSwAlienWithLargeBlackEyesPattern = "3626bpsb"
HeadWithSwBlackEyebrowsAndScarsPattern = "3626bps7"
HeadWithSwBrownEyebrowsPattern = "3626bps2"
HeadWithSwBrownEyebrowsAndBeardPattern = "3626bps9"
HeadWithSwBrownEyebrows_SmileAndBlackChinStrapPattern = "3626cpsg"
HeadWithSwBrownEyebrows_SolidBlackEyesAndBlackChinStrapPattern = "3626cpsf"
HeadWithSwDarkBluishGreyChinStrap_SternEyebrows_BlackGoggles2_SidedPattern = "3626cpsi"
HeadWithSwDarthMaulPattern = "3626bps8"
HeadWithSwFrecklesAndThinBrownEyebrowsPattern = "3626bpsd"
HeadWithSwGreyBeardAndEyebrowsPattern = "3626bps4"
HeadWithSwGreyEyebrows_Implant2_SidedPattern = "3626bpsc"
HeadWithSwRedLips_BlackEyes_ThinEyebrowsPattern = "3626bps0"
HeadWithSwScoutTrooperBlackVisorPattern = "3626bpse"
HeadWithSwSmallBlackEyebrowsPattern = "3626bps3"
HeadWithSwSmirkAndBrownEyebrowsPattern = "3626bps5"
HeadWithSwSternBlackEyebrows_PupilsAndOrangeVisorPattern = "3626cpsh"
HeadWithSwTuskenRaiderPattern = "3626bpst"
HeadWithSeverusSnapePattern = "3626bphb"
HeadWithSideburnsAndDroopyMoustacheBlackPattern = "3626bp3n"
HeadWithSideburnsAndDroopyMoustacheBrownPattern = "3626bp3q"
HeadWithSideburns_Goatee_BeardStubble_ScarPattern = "3626bpq2"
HeadWithSilverMaskAndMouthGrillePattern = "3626bp6x"
HeadWithSilverRobotPattern = "3626bp63"
HeadWithSilverSunglassesAndRedHeadsetPattern = "3626bp68"
HeadWithSilverSunglasses_EyebrowsAndThinGrinPattern = "3626cp8h"
HeadWithSingleLargeBlackEyeWithPupilPattern = "3626cp02"
HeadWithSkullType1_Smiling_Pattern = "3626bpaq"
HeadWithSmallBlueMaskPattern = "3626bp6w"
HeadWithSmileAndGoldToothPattern = "3626bp86"
HeadWithSmile_BlackEyebrowsAndWhitePupilsPattern = "3626bp84"
HeadWithSmile_BrownEyebrowsAndWhitePupilsPattern = "3626bp85"
HeadWithSmirk_BlackMoustachePattern = "3626bpa3"
HeadWithSmirk_BlackHairAndGoateePattern = "3626bp82"
HeadWithSmirk_BlackMoustacheAndCleftChinPattern = "3626bpap"
HeadWithSolidStud = "3626a"
HeadWithStandardGrinPattern_HollowStudWithPiercedBase_ = "3626bp01"
HeadWithStandardGrinPattern_HollowStud_ = "3626cp01"
HeadWithStandardGrinPattern_SolidStud_ = "3626ap01"
HeadWithStandardGrinAndEyebrowsPattern = "3626bp05"
HeadWithStandardGrinAndPointedMoustachePattern = "3626bp03"
HeadWithStandardGrinAndSunglassesPattern = "3626bp04"
HeadWithStandardGrin_EyebrowsAndMicrophonePattern = "3626bp06"
HeadWithStandardWomanPattern = "3626bp02"
HeadWithStubble_MoustacheAndSmirkPattern = "3626bpa5"
HeadWithTanEyebrowsAndFrownPattern = "3626bph2"
HeadWithTeeth_Pupils_BrownEyebrowsPattern = "3626bp0b"
HeadWithThickAngryMoustache_StubbleAndLongHairPattern = "3626bpw1"
HeadWithThickBlackEyebrows_LavenderBlackEye_AdhesiveBandageAndFrownPattern = "3626cpcf4"
HeadWithThickBlackEyebrows_RedEyesWithWhitePupils_LightBluishGreyEyeShadowAndFangsPattern = "3626bpc25"
HeadWithThickBlackMoustacheAndEyebrows_GrinWithTeeth = "3626bpc21"
HeadWithThickMoustacheAndShortEyebrowsPattern = "3626bp0c"
HeadWithThinMoustache_StubbleAndSideburnsPattern = "3626bp67"
HeadWithTribalPaintAndFrownPattern = "3626bpac"
HeadWithVillainBlackFacialHairPattern = "3626bpa4"
HeadWithVillainousGlasses_BlackFacialHairPattern = "3626bpa9"
HeadWithVincentCrabbe_RonWeasley2_SidedPattern = "3626bph5"
HeadWithWhiteHair_Eyebrows_AndMoustachePattern = "3626bpn1"
HeadWithWhiteHeadbandAndFleshCheekLines_SmirkPattern = "3626cpd61"
HeadWithWhiteSkullMask_YellowEyesAndWhiteStringTiedInBackPattern = "3626cpceb"
HeadWithWhiteAndBlueStripesOnCheeks_BlackEyebrowsAndBigGrinPattern = "3626bpc33"
HeadWithWhiteAndLightBluishGreyBushyEyebrows_OpenMouthSmilePattern = "3626bp0h"
HeadWithWhiteAndLightBluishGreyEyebrows_MoustachAndGoatee_DarkOrangeWrinkles_ConcernedExpressionPattern = "3626cpnd"
HeadWithWideSmile_RedLipsAndCrow_SFeetPattern = "3626bpb3"
HeadWithWiryMoustache_GoateeAndEyebrowsPattern = "3626bp3e"
HeadWithYellowEyesAndMouthAndAluminumFoilBlotchesPattern = "3626cp8f"
HelmetWithWingsAndEagleHead = "24088"
MartianHeadWithClip = "30529"
MartianHeadWithClipWithEyelashesPattern = "30529p02"
MartianHeadWithClipWithEyesPlainPattern = "30529p01"
MechanicalHeadSwBattleDroid = "30378"
MechanicalHeadSwBattleDroidWithDarkRedInsigniaPattern = "30378ps2"
MechanicalHeadSwBattleDroidWithOrangeInsigniaPattern = "30378ps1"
MechanicalHeadSwBattleDroidWithYellowInsigniaPattern = "30378ps3"
Pike_SpearElaborateWithFlatSilverHead = "90391p02"
Pike_SpearElaborateWithMetallicSilverHead = "90391p01"
ShieldOvoidWithBullHeadPattern = "2586p4g"
ShieldOvoidWithBullHeadOnBrownBorderSticker = "2586d01"
ShieldTriangularLongWithBearHeadOnDarkRedAndRedBackgroundPattern = "18836p40"
ToolScrewdriverWithWideHeadAnd3_RibHandle = "604550"
