# coding=utf-8
"""
library/parts.py - Auto-generated Part classes for the Python ldraw package.

Copyright (C) 2018 Matthieu Berthomé <rienafairefr@gmail.com>

This file is part of the ldraw Python package.

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.


<< This file is auto-generated, you shouldn't have to modify it>>
"""

__all__ = [
    'accessories',
    'hats',
    'heads',
    'torsos',
    'legs',
    'arms',
    'hands',
]
