# coding=utf-8
"""
library/parts.py - Auto-generated Part classes for the Python ldraw package.

Copyright (C) 2018 Matthieu Berthomé <rienafairefr@gmail.com>

This file is part of the ldraw Python package.

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.


<< This file is auto-generated, you shouldn't have to modify it>>
"""
# pylint: disable=invalid-name, line-too-long, too-many-lines

FoodTurkeyLeg = "33057"
LegLeft = "3817b"
LegLeftWith2SafetyPinsPattern = "3817pc44"
LegLeftWith_Emmet_Badge_ReflectiveStripePattern = "3817p8h"
LegLeftWith_Emmet_Badge_ReflectiveStripeAndSilverTrianglesOnFeetPattern = "3817p8i"
LegLeftWith2RedDiamondsPattern = "3817pba"
LegLeftWithAstroPattern = "3817p6f"
LegLeftWithBlue_WhiteTriangles_FringePattern = "3817pw2"
LegLeftWithButtonedPocketPattern = "3817pa3"
LegLeftWithClockworkRobotPattern = "3817pc67"
LegLeftWithDarkRedLoinclothAndWhiteClawsPattern = "3817paw"
LegLeftWithDarkTurquoise_WhiteTriangles_WhiteFringePattern = "3817pw3"
LegLeftWithDarkblueLoinclothPattern = "3817pq0"
LegLeftWithDarkblueAndGoldLoinclothPattern = "3817pq1"
LegLeftWithGoldenCircuitPattern = "3817p6w"
LegLeftWithGrassSkirtPattern = "3817p3j"
LegLeftWithGreenKiltAndToesPattern = "3817pa2"
LegLeftWithHolsterAndBeltPattern = "3817pa9"
LegLeftWithIronManArmouredSuitMarkViPattern = "3817pbb"
LegLeftWithIronManArmouredSuitMarkViiPattern = "3817pbc"
LegLeftWithIronManArmouredSuitMarkXliiPattern = "3817pbf"
LegLeftWithIronManArmouredSuitMarkXviiPattern = "3817pbe"
LegLeftWithIronPatriotArmouredSuitKneepadPattern = "3817pbg"
LegLeftWithLotrCoatAndShirttailsPattern = "3817pm2"
LegLeftWithLotrLeatherArmorPattern = "3817pm0"
LegLeftWithLotrScaleArmorPattern = "3817pm1"
LegLeftWithLaboratorySmockPattern = "3817pde"
LegLeftWithLeatherStraps_RedStuds_Pattern = "3817p4f"
LegLeftWithOrangeCablePattern = "3817p6u"
LegLeftWithPurpleGreatcoatPattern = "3817phb"
LegLeftWithRedRomanTunicAndBeltPattern = "3817pc6a"
LegLeftWithRed_WhiteTrianglesPattern = "3817pw1"
LegLeftWithRobotPattern = "3817p63"
LegLeftWithSwStormtrooperPattern = "3817psk"
LegLeftWithSwWhiteLeggingsPattern = "3817ps0"
LegLeftWithSalmonCablePattern = "3817p6v"
LegLeftWithWarMachineArmouredSuitKneepadPattern = "3817pbd"
LegLeftWithWhiteApronPattern = "3817p89"
LegRight = "3816b"
LegRightWith3BlackDiamondsPattern = "3816pba"
LegRightWithAstroPattern = "3816p6f"
LegRightWithBlue_WhiteTriangles_FringePattern = "3816pw2"
LegRightWithButtonedPocketPattern = "3816pa3"
LegRightWithChainlinkAnd3SafetyPinsPattern = "3816pc44"
LegRightWithClockworkRobotPattern = "3816pc67"
LegRightWithDarkRedLoincloth_WhiteClawsAndFurTailPattern = "3816paw"
LegRightWithDarkTurquoise_WhiteTriangles_WhiteFringePattern = "3816pw3"
LegRightWithDarkblueLoinclothPattern = "3816pq0"
LegRightWithDarkblueAndGoldLoinclothPattern = "3816pq1"
LegRightWithGoldenCircuitPattern = "3816p6w"
LegRightWithGrassSkirtPattern = "3816p3j"
LegRightWithGreenKiltAndToesPattern = "3816pa2"
LegRightWithHolsterAndBeltPattern = "3816pa9"
LegRightWithIronManArmouredSuitMarkViPattern = "3816pbb"
LegRightWithIronManArmouredSuitMarkViiPattern = "3816pbc"
LegRightWithIronManArmouredSuitMarkXliiPattern = "3816pbf"
LegRightWithIronManArmouredSuitMarkXviiPattern = "3816pbe"
LegRightWithIronPatriotArmouredSuitKneepadPattern = "3816pbg"
LegRightWithLotrCoatAndShirttailsPattern = "3816pm2"
LegRightWithLotrLeatherArmorPattern = "3816pm0"
LegRightWithLotrScaleArmorPattern = "3816pm1"
LegRightWithLaboratorySmockPattern = "3816pde"
LegRightWithLeatherStraps_RedStuds_Pattern = "3816p4f"
LegRightWithOrangeCablePattern = "3816p6u"
LegRightWithPurpleGreatcoatPattern = "3816phb"
LegRightWithRedRomanTunicAndBeltPattern = "3816pc6a"
LegRightWithRed_WhiteTriangles_FringePattern = "3816pw1"
LegRightWithReflectiveStripePattern = "3816p8h"
LegRightWithReflectiveStripeAndTrianglesOnFeetPattern = "3816p8i"
LegRightWithRobotPattern = "3816p63"
LegRightWithSwGunbeltPattern = "3816ps5"
LegRightWithSwStormtrooperPattern = "3816psk"
LegRightWithSwWhiteLeggingsPattern = "3816ps0"
LegRightWithSalmonCablePattern = "3816p6v"
LegRightWithWarMachineArmouredSuitKneepadPattern = "3816pbd"
LegRightWithWhiteApronPattern = "3816p89"
LegRightWithWhiteAndGoldMarkingsPattern = "3816p6g"
LegWooden = "2532"
MechanicalLeg = "53984"
RobotLeg1X2X1_667WithPin = "17486"
RobotLeg1X2X2_333WithPin = "30362a"
SkeletonLeg = "6266"
SkeletonLegLong = "23769"
SkeletonLegWithBlackSquareFoot = "93062p01"
SkeletonLegWithPearlDarkGreySquareFoot = "93062p02"
SkeletonLegWithSquareFoot = "93062"
