# coding=utf-8
"""
colours.py - Colour definitions for the Python ldraw package.

Copyright (C) 2008 David Boddie <david@boddie.org.uk>
(C) 2018 Matthieu Berthomé <rienafairefr@gmail.com>

This file is part of the ldraw Python package.

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.
<< Autogenerated source file >>
"""
# pylint: disable=invalid-name
from ldraw.colour import Colour

Black = Colour(0, "Black", "#05131D", 255, [])
Blue = Colour(1, "Blue", "#0055BF", 255, [])
Green = Colour(2, "Green", "#257A3E", 255, [])
Dark_Turquoise = Colour(3, "Dark_Turquoise", "#00838F", 255, [])
Red = Colour(4, "Red", "#C91A09", 255, [])
Dark_Pink = Colour(5, "Dark_Pink", "#C870A0", 255, [])
Brown = Colour(6, "Brown", "#583927", 255, [])
Light_Grey = Colour(7, "Light_Grey", "#9BA19D", 255, [])
Dark_Grey = Colour(8, "Dark_Grey", "#6D6E5C", 255, [])
Light_Blue = Colour(9, "Light_Blue", "#B4D2E3", 255, [])
Bright_Green = Colour(10, "Bright_Green", "#4B9F4A", 255, [])
Light_Turquoise = Colour(11, "Light_Turquoise", "#55A5AF", 255, [])
Salmon = Colour(12, "Salmon", "#F2705E", 255, [])
Pink = Colour(13, "Pink", "#FC97AC", 255, [])
Yellow = Colour(14, "Yellow", "#F2CD37", 255, [])
White = Colour(15, "White", "#FFFFFF", 255, [])
Main_Colour = Colour(16, "Main_Colour", "#FFFF80", 255, [])
Light_Green = Colour(17, "Light_Green", "#C2DAB8", 255, [])
Light_Yellow = Colour(18, "Light_Yellow", "#FBE696", 255, [])
Tan = Colour(19, "Tan", "#E4CD9E", 255, [])
Light_Violet = Colour(20, "Light_Violet", "#C9CAE2", 255, [])
Glow_In_Dark_Opaque = Colour(21, "Glow_In_Dark_Opaque", "#E0FFB0", 240, [])
Purple = Colour(22, "Purple", "#81007B", 255, [])
Dark_Blue_Violet = Colour(23, "Dark_Blue_Violet", "#2032B0", 255, [])
Edge_Colour = Colour(24, "Edge_Colour", "#7F7F7F", 255, [])
Orange = Colour(25, "Orange", "#FE8A18", 255, [])
Magenta = Colour(26, "Magenta", "#923978", 255, [])
Lime = Colour(27, "Lime", "#BBE90B", 255, [])
Dark_Tan = Colour(28, "Dark_Tan", "#958A73", 255, [])
Bright_Pink = Colour(29, "Bright_Pink", "#E4ADC8", 255, [])
Medium_Lavender = Colour(30, "Medium_Lavender", "#AC78BA", 255, [])
Lavender = Colour(31, "Lavender", "#E1D5ED", 255, [])
Trans_Black_Ir_Lens = Colour(32, "Trans_Black_Ir_Lens", "#000000", 210, [])
Trans_Dark_Blue = Colour(33, "Trans_Dark_Blue", "#0020A0", 128, [])
Trans_Green = Colour(34, "Trans_Green", "#237841", 128, [])
Trans_Bright_Green = Colour(35, "Trans_Bright_Green", "#56E646", 128, [])
Trans_Red = Colour(36, "Trans_Red", "#C91A09", 128, [])
Trans_Dark_Pink = Colour(37, "Trans_Dark_Pink", "#DF6695", 128, [])
Trans_Neon_Orange = Colour(38, "Trans_Neon_Orange", "#FF800D", 128, [])
Trans_Very_Light_Blue = Colour(39, "Trans_Very_Light_Blue", "#C1DFF0", 128, [])
Trans_Black = Colour(40, "Trans_Black", "#635F52", 128, [])
Trans_Medium_Blue = Colour(41, "Trans_Medium_Blue", "#559AB7", 128, [])
Trans_Neon_Green = Colour(42, "Trans_Neon_Green", "#C0FF00", 128, [])
Trans_Light_Blue = Colour(43, "Trans_Light_Blue", "#AEE9EF", 128, [])
Trans_Bright_Reddish_Lilac = Colour(44, "Trans_Bright_Reddish_Lilac", "#96709F", 128, [])
Trans_Pink = Colour(45, "Trans_Pink", "#FC97AC", 128, [])
Trans_Yellow = Colour(46, "Trans_Yellow", "#F5CD2F", 128, [])
Trans_Clear = Colour(47, "Trans_Clear", "#FCFCFC", 128, [])
Trans_Purple = Colour(52, "Trans_Purple", "#A5A5CB", 128, [])
Trans_Neon_Yellow = Colour(54, "Trans_Neon_Yellow", "#DAB000", 128, [])
Trans_Orange = Colour(57, "Trans_Orange", "#F08F1C", 128, [])
Chrome_Antique_Brass = Colour(60, "Chrome_Antique_Brass", "#645A4C", 255, ['CHROME'])
Chrome_Blue = Colour(61, "Chrome_Blue", "#6C96BF", 255, ['CHROME'])
Chrome_Green = Colour(62, "Chrome_Green", "#3CB371", 255, ['CHROME'])
Chrome_Pink = Colour(63, "Chrome_Pink", "#AA4D8E", 255, ['CHROME'])
Chrome_Black = Colour(64, "Chrome_Black", "#1B2A34", 255, ['CHROME'])
Rubber_Yellow = Colour(65, "Rubber_Yellow", "#F5CD2F", 255, ['RUBBER'])
Rubber_Trans_Yellow = Colour(66, "Rubber_Trans_Yellow", "#CAB000", 128, ['RUBBER'])
Rubber_Trans_Clear = Colour(67, "Rubber_Trans_Clear", "#FFFFFF", 128, ['RUBBER'])
Very_Light_Orange = Colour(68, "Very_Light_Orange", "#F3CF9B", 255, [])
Bright_Reddish_Lilac = Colour(69, "Bright_Reddish_Lilac", "#CD6298", 255, [])
Reddish_Brown = Colour(70, "Reddish_Brown", "#582A12", 255, [])
Light_Bluish_Grey = Colour(71, "Light_Bluish_Grey", "#A0A5A9", 255, [])
Dark_Bluish_Grey = Colour(72, "Dark_Bluish_Grey", "#6C6E68", 255, [])
Medium_Blue = Colour(73, "Medium_Blue", "#5C9DD1", 255, [])
Medium_Green = Colour(74, "Medium_Green", "#73DCA1", 255, [])
Speckle_Black_Copper = Colour(75, "Speckle_Black_Copper", "#000000", 255, [])
Speckle_Dark_Bluish_Grey_Silver = Colour(76, "Speckle_Dark_Bluish_Grey_Silver", "#635F61", 255, [])
Light_Pink = Colour(77, "Light_Pink", "#FECCCF", 255, [])
Light_Flesh = Colour(78, "Light_Flesh", "#F6D7B3", 255, [])
Milky_White = Colour(79, "Milky_White", "#FFFFFF", 240, [])
Metallic_Silver = Colour(80, "Metallic_Silver", "#A5A9B4", 255, ['METAL'])
Metallic_Green = Colour(81, "Metallic_Green", "#899B5F", 255, ['METAL'])
Metallic_Gold = Colour(82, "Metallic_Gold", "#DBAC34", 255, ['METAL'])
Metallic_Black = Colour(83, "Metallic_Black", "#1A2831", 255, ['METAL'])
Medium_Dark_Flesh = Colour(84, "Medium_Dark_Flesh", "#CC702A", 255, [])
Medium_Lilac = Colour(85, "Medium_Lilac", "#3F3691", 255, [])
Dark_Flesh = Colour(86, "Dark_Flesh", "#7C503A", 255, [])
Metallic_Dark_Grey = Colour(87, "Metallic_Dark_Grey", "#6D6E5C", 255, ['METAL'])
Blue_Violet = Colour(89, "Blue_Violet", "#4C61DB", 255, [])
Flesh = Colour(92, "Flesh", "#D09168", 255, [])
Light_Salmon = Colour(100, "Light_Salmon", "#FEBABD", 255, [])
Violet = Colour(110, "Violet", "#4354A3", 255, [])
Medium_Violet = Colour(112, "Medium_Violet", "#6874CA", 255, [])
Glitter_Trans_Dark_Pink = Colour(114, "Glitter_Trans_Dark_Pink", "#DF6695", 128, [])
Medium_Lime = Colour(115, "Medium_Lime", "#C7D23C", 255, [])
Glitter_Trans_Clear = Colour(117, "Glitter_Trans_Clear", "#FFFFFF", 128, [])
Aqua = Colour(118, "Aqua", "#B3D7D1", 255, [])
Light_Lime = Colour(120, "Light_Lime", "#D9E4A7", 255, [])
Light_Orange = Colour(125, "Light_Orange", "#F9BA61", 255, [])
Dark_Nougat = Colour(128, "Dark_Nougat", "#AD6140", 255, [])
Glitter_Trans_Purple = Colour(129, "Glitter_Trans_Purple", "#640061", 128, [])
Speckle_Black_Silver = Colour(132, "Speckle_Black_Silver", "#000000", 255, [])
Speckle_Black_Gold = Colour(133, "Speckle_Black_Gold", "#000000", 255, [])
Copper = Colour(134, "Copper", "#964A27", 255, ['PEARLESCENT'])
Pearl_Light_Grey = Colour(135, "Pearl_Light_Grey", "#9CA3A8", 255, ['PEARLESCENT'])
Metal_Blue = Colour(137, "Metal_Blue", "#5677BA", 255, ['PEARLESCENT'])
Pearl_Light_Gold = Colour(142, "Pearl_Light_Gold", "#DCBE61", 255, ['PEARLESCENT'])
Pearl_Dark_Grey = Colour(148, "Pearl_Dark_Grey", "#575857", 255, ['PEARLESCENT'])
Pearl_Very_Light_Grey = Colour(150, "Pearl_Very_Light_Grey", "#BBBDBC", 255, ['PEARLESCENT'])
Very_Light_Bluish_Grey = Colour(151, "Very_Light_Bluish_Grey", "#E6E3E0", 255, [])
Flat_Dark_Gold = Colour(178, "Flat_Dark_Gold", "#B4883E", 255, ['PEARLESCENT'])
Flat_Silver = Colour(179, "Flat_Silver", "#898788", 255, ['PEARLESCENT'])
Pearl_White = Colour(183, "Pearl_White", "#F2F3F2", 255, ['PEARLESCENT'])
Metallic_Bright_Red = Colour(184, "Metallic_Bright_Red", "#D60026", 255, ['METAL'])
Metallic_Dark_Green = Colour(186, "Metallic_Dark_Green", "#008E3C", 255, ['METAL'])
Reddish_Gold = Colour(189, "Reddish_Gold", "#AC8247", 255, ['PEARLESCENT'])
Bright_Light_Orange = Colour(191, "Bright_Light_Orange", "#F8BB3D", 255, [])
Bright_Light_Blue = Colour(212, "Bright_Light_Blue", "#86C1E1", 255, [])
Rust = Colour(216, "Rust", "#B31004", 255, [])
Reddish_Lilac = Colour(218, "Reddish_Lilac", "#8E5597", 255, [])
Lilac = Colour(219, "Lilac", "#564E9D", 255, [])
Bright_Light_Yellow = Colour(226, "Bright_Light_Yellow", "#FFF03A", 255, [])
Trans_Bright_Light_Orange = Colour(231, "Trans_Bright_Light_Orange", "#FCB76D", 128, [])
Sky_Blue = Colour(232, "Sky_Blue", "#56BED6", 255, [])
Trans_Fire_Yellow = Colour(234, "Trans_Fire_Yellow", "#FBE890", 128, [])
Rubber_Black = Colour(256, "Rubber_Black", "#212121", 255, ['RUBBER'])
Dark_Blue = Colour(272, "Dark_Blue", "#0D325B", 255, [])
Rubber_Blue = Colour(273, "Rubber_Blue", "#0033B2", 255, ['RUBBER'])
Trans_Reddish_Lilac = Colour(284, "Trans_Reddish_Lilac", "#C281A5", 128, [])
Trans_Light_Green = Colour(285, "Trans_Light_Green", "#7DC291", 128, [])
Dark_Green = Colour(288, "Dark_Green", "#184632", 255, [])
Trans_Light_Blue_Violet = Colour(293, "Trans_Light_Blue_Violet", "#6BABE4", 128, [])
Glow_In_Dark_Trans = Colour(294, "Glow_In_Dark_Trans", "#BDC6AD", 240, [])
Flamingo_Pink = Colour(295, "Flamingo_Pink", "#FF94C2", 255, [])
Pearl_Gold = Colour(297, "Pearl_Gold", "#CC9C2B", 255, ['PEARLESCENT'])
Metallic_Copper = Colour(300, "Metallic_Copper", "#C27F53", 255, ['METAL'])
Glitter_Trans_Light_Blue = Colour(302, "Glitter_Trans_Light_Blue", "#AEE9EF", 128, [])
Dark_Brown = Colour(308, "Dark_Brown", "#352100", 255, [])
Maersk_Blue = Colour(313, "Maersk_Blue", "#54A9C8", 255, [])
Dark_Red = Colour(320, "Dark_Red", "#720E0F", 255, [])
Dark_Azure = Colour(321, "Dark_Azure", "#1498D7", 255, [])
Medium_Azure = Colour(322, "Medium_Azure", "#3EC2DD", 255, [])
Light_Aqua = Colour(323, "Light_Aqua", "#BDDCD8", 255, [])
Rubber_Red = Colour(324, "Rubber_Red", "#C40026", 255, ['RUBBER'])
Yellowish_Green = Colour(326, "Yellowish_Green", "#DFEEA5", 255, [])
Glow_In_Dark_White = Colour(329, "Glow_In_Dark_White", "#F5F3D7", 240, [])
Olive_Green = Colour(330, "Olive_Green", "#9B9A5A", 255, [])
Chrome_Gold = Colour(334, "Chrome_Gold", "#BBA53D", 255, ['CHROME'])
Sand_Red = Colour(335, "Sand_Red", "#D67572", 255, [])
Glitter_Trans_Neon_Green = Colour(339, "Glitter_Trans_Neon_Green", "#C0FF00", 128, [])
Rubber_Orange = Colour(350, "Rubber_Orange", "#D06610", 255, ['RUBBER'])
Medium_Dark_Pink = Colour(351, "Medium_Dark_Pink", "#F785B1", 255, [])
Earth_Orange = Colour(366, "Earth_Orange", "#FA9C1C", 255, [])
Sand_Purple = Colour(373, "Sand_Purple", "#845E84", 255, [])
Rubber_Light_Grey = Colour(375, "Rubber_Light_Grey", "#C1C2C1", 255, ['RUBBER'])
Sand_Green = Colour(378, "Sand_Green", "#A0BCAC", 255, [])
Sand_Blue = Colour(379, "Sand_Blue", "#597184", 255, [])
Chrome_Silver = Colour(383, "Chrome_Silver", "#E0E0E0", 255, ['CHROME'])
Rubber_Dark_Blue = Colour(406, "Rubber_Dark_Blue", "#001D68", 255, ['RUBBER'])
Rubber_Purple = Colour(449, "Rubber_Purple", "#81007B", 255, ['RUBBER'])
Fabuland_Brown = Colour(450, "Fabuland_Brown", "#B67B50", 255, [])
Medium_Orange = Colour(462, "Medium_Orange", "#FFA70B", 255, [])
Dark_Orange = Colour(484, "Dark_Orange", "#A95500", 255, [])
Rubber_Lime = Colour(490, "Rubber_Lime", "#D7F000", 255, ['RUBBER'])
Magnet = Colour(493, "Magnet", "#656761", 255, ['METAL'])
Electric_Contact_Alloy = Colour(494, "Electric_Contact_Alloy", "#D0D0D0", 255, ['METAL'])
Electric_Contact_Copper = Colour(495, "Electric_Contact_Copper", "#AE7A59", 255, ['METAL'])
Rubber_Light_Bluish_Grey = Colour(496, "Rubber_Light_Bluish_Grey", "#A3A2A4", 255, ['RUBBER'])
Very_Light_Grey = Colour(503, "Very_Light_Grey", "#E6E3DA", 255, [])
Rubber_Flat_Silver = Colour(504, "Rubber_Flat_Silver", "#898788", 255, ['RUBBER'])
Rubber_White = Colour(511, "Rubber_White", "#FAFAFA", 255, ['RUBBER'])

ColoursByCode = {
    0: Black,
    1: Blue,
    2: Green,
    3: Dark_Turquoise,
    4: Red,
    5: Dark_Pink,
    6: Brown,
    7: Light_Grey,
    8: Dark_Grey,
    9: Light_Blue,
    10: Bright_Green,
    11: Light_Turquoise,
    12: Salmon,
    13: Pink,
    14: Yellow,
    15: White,
    16: Main_Colour,
    17: Light_Green,
    18: Light_Yellow,
    19: Tan,
    20: Light_Violet,
    21: Glow_In_Dark_Opaque,
    22: Purple,
    23: Dark_Blue_Violet,
    24: Edge_Colour,
    25: Orange,
    26: Magenta,
    27: Lime,
    28: Dark_Tan,
    29: Bright_Pink,
    30: Medium_Lavender,
    31: Lavender,
    32: Trans_Black_Ir_Lens,
    33: Trans_Dark_Blue,
    34: Trans_Green,
    35: Trans_Bright_Green,
    36: Trans_Red,
    37: Trans_Dark_Pink,
    38: Trans_Neon_Orange,
    39: Trans_Very_Light_Blue,
    40: Trans_Black,
    41: Trans_Medium_Blue,
    42: Trans_Neon_Green,
    43: Trans_Light_Blue,
    44: Trans_Bright_Reddish_Lilac,
    45: Trans_Pink,
    46: Trans_Yellow,
    47: Trans_Clear,
    52: Trans_Purple,
    54: Trans_Neon_Yellow,
    57: Trans_Orange,
    60: Chrome_Antique_Brass,
    61: Chrome_Blue,
    62: Chrome_Green,
    63: Chrome_Pink,
    64: Chrome_Black,
    65: Rubber_Yellow,
    66: Rubber_Trans_Yellow,
    67: Rubber_Trans_Clear,
    68: Very_Light_Orange,
    69: Bright_Reddish_Lilac,
    70: Reddish_Brown,
    71: Light_Bluish_Grey,
    72: Dark_Bluish_Grey,
    73: Medium_Blue,
    74: Medium_Green,
    75: Speckle_Black_Copper,
    76: Speckle_Dark_Bluish_Grey_Silver,
    77: Light_Pink,
    78: Light_Flesh,
    79: Milky_White,
    80: Metallic_Silver,
    81: Metallic_Green,
    82: Metallic_Gold,
    83: Metallic_Black,
    84: Medium_Dark_Flesh,
    85: Medium_Lilac,
    86: Dark_Flesh,
    87: Metallic_Dark_Grey,
    89: Blue_Violet,
    92: Flesh,
    100: Light_Salmon,
    110: Violet,
    112: Medium_Violet,
    114: Glitter_Trans_Dark_Pink,
    115: Medium_Lime,
    117: Glitter_Trans_Clear,
    118: Aqua,
    120: Light_Lime,
    125: Light_Orange,
    128: Dark_Nougat,
    129: Glitter_Trans_Purple,
    132: Speckle_Black_Silver,
    133: Speckle_Black_Gold,
    134: Copper,
    135: Pearl_Light_Grey,
    137: Metal_Blue,
    142: Pearl_Light_Gold,
    148: Pearl_Dark_Grey,
    150: Pearl_Very_Light_Grey,
    151: Very_Light_Bluish_Grey,
    178: Flat_Dark_Gold,
    179: Flat_Silver,
    183: Pearl_White,
    184: Metallic_Bright_Red,
    186: Metallic_Dark_Green,
    189: Reddish_Gold,
    191: Bright_Light_Orange,
    212: Bright_Light_Blue,
    216: Rust,
    218: Reddish_Lilac,
    219: Lilac,
    226: Bright_Light_Yellow,
    231: Trans_Bright_Light_Orange,
    232: Sky_Blue,
    234: Trans_Fire_Yellow,
    256: Rubber_Black,
    272: Dark_Blue,
    273: Rubber_Blue,
    284: Trans_Reddish_Lilac,
    285: Trans_Light_Green,
    288: Dark_Green,
    293: Trans_Light_Blue_Violet,
    294: Glow_In_Dark_Trans,
    295: Flamingo_Pink,
    297: Pearl_Gold,
    300: Metallic_Copper,
    302: Glitter_Trans_Light_Blue,
    308: Dark_Brown,
    313: Maersk_Blue,
    320: Dark_Red,
    321: Dark_Azure,
    322: Medium_Azure,
    323: Light_Aqua,
    324: Rubber_Red,
    326: Yellowish_Green,
    329: Glow_In_Dark_White,
    330: Olive_Green,
    334: Chrome_Gold,
    335: Sand_Red,
    339: Glitter_Trans_Neon_Green,
    350: Rubber_Orange,
    351: Medium_Dark_Pink,
    366: Earth_Orange,
    373: Sand_Purple,
    375: Rubber_Light_Grey,
    378: Sand_Green,
    379: Sand_Blue,
    383: Chrome_Silver,
    406: Rubber_Dark_Blue,
    449: Rubber_Purple,
    450: Fabuland_Brown,
    462: Medium_Orange,
    484: Dark_Orange,
    490: Rubber_Lime,
    493: Magnet,
    494: Electric_Contact_Alloy,
    495: Electric_Contact_Copper,
    496: Rubber_Light_Bluish_Grey,
    503: Very_Light_Grey,
    504: Rubber_Flat_Silver,
    511: Rubber_White,
}

ColoursByName = {
    "Black": Black,
    "Blue": Blue,
    "Green": Green,
    "Dark_Turquoise": Dark_Turquoise,
    "Red": Red,
    "Dark_Pink": Dark_Pink,
    "Brown": Brown,
    "Light_Grey": Light_Grey,
    "Dark_Grey": Dark_Grey,
    "Light_Blue": Light_Blue,
    "Bright_Green": Bright_Green,
    "Light_Turquoise": Light_Turquoise,
    "Salmon": Salmon,
    "Pink": Pink,
    "Yellow": Yellow,
    "White": White,
    "Main_Colour": Main_Colour,
    "Light_Green": Light_Green,
    "Light_Yellow": Light_Yellow,
    "Tan": Tan,
    "Light_Violet": Light_Violet,
    "Glow_In_Dark_Opaque": Glow_In_Dark_Opaque,
    "Purple": Purple,
    "Dark_Blue_Violet": Dark_Blue_Violet,
    "Edge_Colour": Edge_Colour,
    "Orange": Orange,
    "Magenta": Magenta,
    "Lime": Lime,
    "Dark_Tan": Dark_Tan,
    "Bright_Pink": Bright_Pink,
    "Medium_Lavender": Medium_Lavender,
    "Lavender": Lavender,
    "Trans_Black_IR_Lens": Trans_Black_Ir_Lens,
    "Trans_Dark_Blue": Trans_Dark_Blue,
    "Trans_Green": Trans_Green,
    "Trans_Bright_Green": Trans_Bright_Green,
    "Trans_Red": Trans_Red,
    "Trans_Dark_Pink": Trans_Dark_Pink,
    "Trans_Neon_Orange": Trans_Neon_Orange,
    "Trans_Very_Light_Blue": Trans_Very_Light_Blue,
    "Trans_Black": Trans_Black,
    "Trans_Medium_Blue": Trans_Medium_Blue,
    "Trans_Neon_Green": Trans_Neon_Green,
    "Trans_Light_Blue": Trans_Light_Blue,
    "Trans_Bright_Reddish_Lilac": Trans_Bright_Reddish_Lilac,
    "Trans_Pink": Trans_Pink,
    "Trans_Yellow": Trans_Yellow,
    "Trans_Clear": Trans_Clear,
    "Trans_Purple": Trans_Purple,
    "Trans_Neon_Yellow": Trans_Neon_Yellow,
    "Trans_Orange": Trans_Orange,
    "Chrome_Antique_Brass": Chrome_Antique_Brass,
    "Chrome_Blue": Chrome_Blue,
    "Chrome_Green": Chrome_Green,
    "Chrome_Pink": Chrome_Pink,
    "Chrome_Black": Chrome_Black,
    "Rubber_Yellow": Rubber_Yellow,
    "Rubber_Trans_Yellow": Rubber_Trans_Yellow,
    "Rubber_Trans_Clear": Rubber_Trans_Clear,
    "Very_Light_Orange": Very_Light_Orange,
    "Bright_Reddish_Lilac": Bright_Reddish_Lilac,
    "Reddish_Brown": Reddish_Brown,
    "Light_Bluish_Grey": Light_Bluish_Grey,
    "Dark_Bluish_Grey": Dark_Bluish_Grey,
    "Medium_Blue": Medium_Blue,
    "Medium_Green": Medium_Green,
    "Speckle_Black_Copper": Speckle_Black_Copper,
    "Speckle_Dark_Bluish_Grey_Silver": Speckle_Dark_Bluish_Grey_Silver,
    "Light_Pink": Light_Pink,
    "Light_Flesh": Light_Flesh,
    "Milky_White": Milky_White,
    "Metallic_Silver": Metallic_Silver,
    "Metallic_Green": Metallic_Green,
    "Metallic_Gold": Metallic_Gold,
    "Metallic_Black": Metallic_Black,
    "Medium_Dark_Flesh": Medium_Dark_Flesh,
    "Medium_Lilac": Medium_Lilac,
    "Dark_Flesh": Dark_Flesh,
    "Metallic_Dark_Grey": Metallic_Dark_Grey,
    "Blue_Violet": Blue_Violet,
    "Flesh": Flesh,
    "Light_Salmon": Light_Salmon,
    "Violet": Violet,
    "Medium_Violet": Medium_Violet,
    "Glitter_Trans_Dark_Pink": Glitter_Trans_Dark_Pink,
    "Medium_Lime": Medium_Lime,
    "Glitter_Trans_Clear": Glitter_Trans_Clear,
    "Aqua": Aqua,
    "Light_Lime": Light_Lime,
    "Light_Orange": Light_Orange,
    "Dark_Nougat": Dark_Nougat,
    "Glitter_Trans_Purple": Glitter_Trans_Purple,
    "Speckle_Black_Silver": Speckle_Black_Silver,
    "Speckle_Black_Gold": Speckle_Black_Gold,
    "Copper": Copper,
    "Pearl_Light_Grey": Pearl_Light_Grey,
    "Metal_Blue": Metal_Blue,
    "Pearl_Light_Gold": Pearl_Light_Gold,
    "Pearl_Dark_Grey": Pearl_Dark_Grey,
    "Pearl_Very_Light_Grey": Pearl_Very_Light_Grey,
    "Very_Light_Bluish_Grey": Very_Light_Bluish_Grey,
    "Flat_Dark_Gold": Flat_Dark_Gold,
    "Flat_Silver": Flat_Silver,
    "Pearl_White": Pearl_White,
    "Metallic_Bright_Red": Metallic_Bright_Red,
    "Metallic_Dark_Green": Metallic_Dark_Green,
    "Reddish_Gold": Reddish_Gold,
    "Bright_Light_Orange": Bright_Light_Orange,
    "Bright_Light_Blue": Bright_Light_Blue,
    "Rust": Rust,
    "Reddish_Lilac": Reddish_Lilac,
    "Lilac": Lilac,
    "Bright_Light_Yellow": Bright_Light_Yellow,
    "Trans_Bright_Light_Orange": Trans_Bright_Light_Orange,
    "Sky_Blue": Sky_Blue,
    "Trans_Fire_Yellow": Trans_Fire_Yellow,
    "Rubber_Black": Rubber_Black,
    "Dark_Blue": Dark_Blue,
    "Rubber_Blue": Rubber_Blue,
    "Trans_Reddish_Lilac": Trans_Reddish_Lilac,
    "Trans_Light_Green": Trans_Light_Green,
    "Dark_Green": Dark_Green,
    "Trans_Light_Blue_Violet": Trans_Light_Blue_Violet,
    "Glow_In_Dark_Trans": Glow_In_Dark_Trans,
    "Flamingo_Pink": Flamingo_Pink,
    "Pearl_Gold": Pearl_Gold,
    "Metallic_Copper": Metallic_Copper,
    "Glitter_Trans_Light_Blue": Glitter_Trans_Light_Blue,
    "Dark_Brown": Dark_Brown,
    "Maersk_Blue": Maersk_Blue,
    "Dark_Red": Dark_Red,
    "Dark_Azure": Dark_Azure,
    "Medium_Azure": Medium_Azure,
    "Light_Aqua": Light_Aqua,
    "Rubber_Red": Rubber_Red,
    "Yellowish_Green": Yellowish_Green,
    "Glow_In_Dark_White": Glow_In_Dark_White,
    "Olive_Green": Olive_Green,
    "Chrome_Gold": Chrome_Gold,
    "Sand_Red": Sand_Red,
    "Glitter_Trans_Neon_Green": Glitter_Trans_Neon_Green,
    "Rubber_Orange": Rubber_Orange,
    "Medium_Dark_Pink": Medium_Dark_Pink,
    "Earth_Orange": Earth_Orange,
    "Sand_Purple": Sand_Purple,
    "Rubber_Light_Grey": Rubber_Light_Grey,
    "Sand_Green": Sand_Green,
    "Sand_Blue": Sand_Blue,
    "Chrome_Silver": Chrome_Silver,
    "Rubber_Dark_Blue": Rubber_Dark_Blue,
    "Rubber_Purple": Rubber_Purple,
    "Fabuland_Brown": Fabuland_Brown,
    "Medium_Orange": Medium_Orange,
    "Dark_Orange": Dark_Orange,
    "Rubber_Lime": Rubber_Lime,
    "Magnet": Magnet,
    "Electric_Contact_Alloy": Electric_Contact_Alloy,
    "Electric_Contact_Copper": Electric_Contact_Copper,
    "Rubber_Light_Bluish_Grey": Rubber_Light_Bluish_Grey,
    "Very_Light_Grey": Very_Light_Grey,
    "Rubber_Flat_Silver": Rubber_Flat_Silver,
    "Rubber_White": Rubber_White,
}
