# coding=utf-8
"""
library/parts.py - Auto-generated Part classes for the Python ldraw package.

Copyright (C) 2018 Matthieu Berthomé <rienafairefr@gmail.com>

This file is part of the ldraw Python package.

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.


<< This file is auto-generated, you shouldn't have to modify it>>
"""
# pylint: disable=invalid-name, line-too-long, too-many-lines

Cook_SHat = "3898"
HatBeanie = "90541"
HatBeret = "90386"
HatBicorne = "2528"
HatBicorneWithEvilSkullAndCrossbonesPattern = "2528p30"
HatBowler = "95674"
HatBowlerWithBlackQuestionMarkPattern = "95674p02"
HatBowlerWithRedFlowerWithYellowCentrePattern = "95674p01"
HatConicalAsian = "93059"
HatConicalAsianWithCurvedSides = "26007"
HatCowboy = "3629"
HatCowboyWithCavalryLogoPattern = "3629pw1"
HatCowboyWithSilverStarPattern = "3629pw2"
HatCrown = "71015"
HatElfWithPointyEars = "13787"
HatElfWithPointyEarsWithBrightGreenTopPattern = "13787p01"
HatFedora = "61506"
HatFez = "85975"
HatHighConeShaped = "2338"
HatImperialGuardShako = "2545"
HatImperialGuardShakoWithRedPlumeAndGoldBadgePattern = "2545p01"
HatKepi = "30135"
HatKnitCap = "41334"
HatPithHelmet = "30172"
HatPolice = "15530"
HatPoliceWithGoldBadgePattern = "15530p01"
HatRag = "2543"
HatTricorne = "2544"
HatTricorneWithWhitePlume_Complete_ = "2544c01"
HatWideBrimFlat = "30167"
HatWithWideBrimDown = "13788"
PoliceHat = "3624"
TopHat = "3878"
WizardsHat = "6131"
